@@ -1,15 +1,7 @@
-# -*- coding: UTF-8 -*-
-# -------------------------------------------------------------------------------
-# Name:         dp
-# Purpose:      Processing related to Dual-Pol and Differential Phase
-#
-# Authors:      Maik Heistermann, Stephan Jacobi and Thomas Pfaff
-#
-# Created:      20.09.2013
-# Copyright:    (c) Maik Heistermann, Stephan Jacobi and Thomas Pfaff 2011
-# Licence:      The MIT License
-# -------------------------------------------------------------------------------
 #!/usr/bin/env python
+# -*- coding: UTF-8 -*-
+# Copyright (c) 2016, wradlib developers.
+# Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
 Dual-Pol and Differential Phase
@@ -19,28 +11,32 @@ Overview
 --------
 
 This module provides algorithms to process polarimetric radar moments,
-namely the differential phase, PhiDP, and, based on successful PhiDP retrieval,
-also the specific differential phase, KDP. Please note that the actual application
-of polarimetric moments is implemented in the corresponding wradlib modules, e.g.:
+namely the differential phase, :math:`Phi_{DP}`, and, based on successful
+:math:`Phi_{DP}` retrieval, also the specific differential phase,
+:math:`K_{DP}`.
+Please note that the actual application of polarimetric moments is implemented
+in the corresponding wradlib modules, e.g.:
 
-    - fuzzy echo classification from polarimetric moments (:doc:`classify_echo_fuzzy
-      <generated/wradlib.clutter.classify_echo_fuzzy>`)
-    - attenuation correction (:doc:`pia_from_kdp <generated/wradlib.atten.pia_from_kdp>`)
-    - direct precipitation retrieval from Kdp (:doc:`kdp2r <generated/wradlib.trafo.kdp2r>`)
+    - fuzzy echo classification from polarimetric moments
+      (:meth:`wradlib.clutter.classify_echo_fuzzy`)
+    - attenuation correction (:meth:`wradlib.atten.pia_from_kdp`)
+    - direct precipitation retrieval from Kdp (:meth:`wradlib.trafo.kdp2r`)
 
-Establishing a valid PhiDP profile for Kdp retrieval involves despeckling (linear_despeckle),
-phase unfolding, and iterative retrieval of PhiDP form KDP. The main workflow and
-its single steps is based on a publication by Vulpiani :cite:`Vulpiani2012`. For convenience, the
-entire workflow has been put together in the function
-:doc:`process_raw_phidp <generated/wradlib.dp.process_raw_phidp_vulpiani>`.
+Establishing a valid :math:`Phi_{DP}` profile for :math:`K_{DP}` retrieval
+involves despeckling (linear_despeckle), phase unfolding, and iterative
+retrieval of :math:`Phi_{DP}` form :math:`K_{DP}`.
+The main workflow and its single steps is based on a publication by
+:cite:`Vulpiani2012`. For convenience, the entire workflow has been
+put together in the function :meth:`wradlib.dp.process_raw_phidp_vulpiani`.
 
-Once a valid PhiDP profile has been established, the `kdp_from_phidp` functions
-can be used to retrieve Kdp.
+Once a valid :math:`Phi_{DP}` profile has been established, the
+`kdp_from_phidp` functions can be used to retrieve :math:`K_{DP}`.
 
 Please note that so far, the functions in this module were designed to increase
 performance. This was mainly achieved by allowing the simultaneous application
-of functions over multiple array dimensions. The only requirement to apply these
-function is that the **range dimension must be the last dimension** of all input arrays.
+of functions over multiple array dimensions. The only requirement to apply
+these function is that the **range dimension must be the last dimension** of
+all input arrays.
 
 
 .. autosummary::
@@ -49,7 +45,9 @@ function is that the **range dimension must be the last dimension** of all input
 
     process_raw_phidp_vulpiani
     kdp_from_phidp_finitediff
+    kdp_from_phidp_linregress
     kdp_from_phidp_convolution
+    kdp_from_phidp_sobel
     unfold_phi_vulpiani
     unfold_phi
     linear_despeckle
@@ -60,24 +58,26 @@ function is that the **range dimension must be the last dimension** of all input
 import numpy as np
 from scipy.interpolate import interp1d
 from scipy.signal import medfilt
-from scipy.stats import nanmedian, nanmean, linregress
+from scipy.stats import linregress
 from scipy.ndimage.filters import convolve1d
 from . import util as util
 
 
-def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7, niter=2, copy=False):
-    """Establish consistent PhiDP profiles from raw data.
+def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7,
+                               niter=2, copy=False):
+    """Establish consistent :math:`Phi_{DP}` profiles from raw data.
 
-    This approach is based on Vulpiani :cite:`Vulpiani2012` and involves a two step procedure
-    of PhiDP reconstruction.
+    This approach is based on :cite:`Vulpiani2012` and involves a
+    two step procedure of :math:`Phi_{DP}` reconstruction.
 
-    Processing of raw PhiDP data contains the following steps:
+    Processing of raw :math:`Phi_{DP}` data contains the following steps:
 
         - Despeckle
-        - Initial KDP estimation
+        - Initial :math:`K_{DP}` estimation
         - Removal of artifacts
         - Phase unfolding
-        - PhiDP reconstruction using iterative estimation of KDP
+        - :math:`Phi_{DP}` reconstruction using iterative estimation
+          of :math:`K_{DP}`
 
     Parameters
     ----------
@@ -87,9 +87,10 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7, niter=2, copy=Fals
     N_despeckle : integer
         *N* parameter of function dp.linear_despeckle
     L : integer
-        *L* parameter of dp.kdp_from_phidp_convolution
+        *L* parameter of :meth:`~wradlib.dp.kdp_from_phidp_convolution`
     niter : integer
-        Number of iterations in which phidp is retrieved from kdp and vice versa
+        Number of iterations in which phidp is retrieved from kdp
+        and vice versa
     copy : boolean
         if True, the original phidp array will remain unchanged
 
@@ -100,6 +101,11 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7, niter=2, copy=Fals
     kdp : array of shape (n azimuth angles, n range gates)
         kdp estimate corresponding to phidp output
 
+    Examples
+    --------
+
+    See :ref:`notebooks/verification/wradlib_verify_example.ipynb`.
+
     """
     if copy:
         phidp = phidp.copy()
@@ -132,7 +138,8 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7, niter=2, copy=Fals
         phidp = 2 * np.cumsum(kdp, axis=-1) * dr
         # kdp from phidp by convolution
         kdp = kdp_from_phidp_convolution(phidp, dr=dr, L=L)
-        # convert all NaNs to zeros (normally, this line can be assumed to be redundant)
+        # convert all NaNs to zeros (normally, this line can be assumed
+        # to be redundant)
         kdp = _fill_sweep(kdp)
 
     return phidp, kdp
@@ -142,7 +149,7 @@ def unfold_phi_vulpiani(phidp, kdp):
     """Alternative phase unfolding which completely relies on Kdp.
 
     This unfolding should be used in oder to iteratively reconstruct
-    phidp and Kdp (see Vulpiani :cite:`Vulpiani2012`).
+    phidp and Kdp (see :cite:`Vulpiani2012`).
 
     Parameters
     ----------
@@ -193,63 +200,72 @@ def _fill_sweep(dat, kind="nan_to_num", fill_value=0.):
         if len(validx) < 2:
             dat[beam, invalid] = 0.
             continue
-        f = interp1d(validx, dat[beam, validx], kind=kind, bounds_error=False, fill_value=fill_value)
+        f = interp1d(validx, dat[beam, validx], kind=kind,
+                     bounds_error=False, fill_value=fill_value)
         invalidx = np.where(invalid)[0]
         dat[beam, invalidx] = f(invalidx)
     return dat.reshape(shape)
 
 
 def kdp_from_phidp_finitediff(phidp, L=7, dr=1.):
-    """Retrieves Kdp from PhiDP by applying a moving window range finite difference derivative.
+    """Retrieves :math:`K_{DP}` from :math:`Phi_{DP}` by applying a moving
+    window range finite difference derivative.
 
-    See Vulpiani :cite:`Vulpiani2012` for details about this approach.
+    See :cite:`Vulpiani2012` for details about this approach.
 
-    Please note that the moving window size *L* is specified as the number of range
-    gates. Thus, this argument might need adjustment in case the range resolution changes.
-    In the original publication (:cite:`Vulpiani2012`), the value L=7 was chosen for
-    a range resolution of 1km.
+    Please note that the moving window size *L* is specified as the number of
+    range gates. Thus, this argument might need adjustment in case the
+    range resolution changes.
+    In the original publication (:cite:`Vulpiani2012`), the value L=7 was
+    chosen for a range resolution of 1km.
 
     Warning
     -------
     The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension needs
-    to be the LAST dimension of the input array.
+    multiple dimensions in one step. For this purpose, the RANGE dimension
+    needs to be the LAST dimension of the input array.
 
     Parameters
     ----------
     phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the input array.
+        Note that the range dimension must be the last dimension of
+        the input array.
     L : integer
         Width of the window (as number of range gates)
     dr : gate length in km
     """
-    assert (L % 2) == 1, "Window size N for function kdp_from_phidp must be an odd number."
+    assert (L % 2) == 1, \
+        "Window size N for function kdp_from_phidp must be an odd number."
     # Make really sure L is an integer
     L = int(L)
     kdp = np.zeros(phidp.shape)
     for r in range(int(L / 2), phidp.shape[-1] - int(L / 2)):
-        kdp[..., r] = (phidp[..., r + int(L / 2)] - phidp[..., r - int(L / 2)]) / (L - 1)
+        kdp[..., r] = (phidp[..., r + int(L / 2)] -
+                       phidp[..., r - int(L / 2)]) / (L - 1)
     return kdp / 2. / dr
 
 
 def kdp_from_phidp_linregress(phidp, L=7, dr=1.):
-    """Alternative Kdp from PhiDP by applying a moving window linear regression.
+    """Alternative :math:`K_{DP}` from :math:`Phi_{DP}` by applying a moving
+    window linear regression.
 
-    Please note that the moving window size *L* is specified as the number of range
-    gates. Thus, this argument might need adjustment in case the range resolution changes.
-    In the original publication (Vulpiani :cite:`Vulpiani2012`), the value L=7 was chosen for
-    a range resolution of 1km.
+    Please note that the moving window size *L* is specified as the number of
+    range gates. Thus, this argument might need adjustment in case the range
+    resolution changes.
+    In the original publication (:cite:`Vulpiani2012`), the value L=7
+    was chosen for a range resolution of 1km.
 
     Warning
     -------
     The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension needs
-    to be the LAST dimension of the input array.
+    multiple dimensions in one step. For this purpose, the RANGE dimension
+    needs to be the LAST dimension of the input array.
 
     Parameters
     ----------
     phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the input array.
+        Note that the range dimension must be the last dimension of the
+        input array.
     L : integer
         Width of the window (as number of range gates)
     dr : gate length in km
@@ -266,14 +282,15 @@ def kdp_from_phidp_linregress(phidp, L=7, dr=1.):
     >>> gaps = np.concatenate([range(10, 20), range(30, 40), range(60, 80)])
     >>> phidp_raw[gaps] = np.nan
     >>> kdp_re = wradlib.dp.kdp_from_phidp_linregress(phidp_raw)
-    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")
-    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")
+    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")  # noqa
+    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")  # noqa
     >>> line3 = pl.plot(kdp_true, "g-", label="kdp_true")
-    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")
-    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))
+    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")  # noqa
+    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))  # noqa
 
     """
-    assert (L % 2) == 1, "Window size N for function kdp_from_phidp must be an odd number."
+    assert (L % 2) == 1, \
+        "Window size N for function kdp_from_phidp must be an odd number."
 
     shape = phidp.shape
     phidp = phidp.reshape((-1, shape[-1]))
@@ -292,49 +309,55 @@ def kdp_from_phidp_linregress(phidp, L=7, dr=1.):
             if np.sum(valids[beam, ix]) < L / 2:
                 # not enough valid values inside our window
                 continue
-            kdp[beam, r] = linregress(x[ix][valids[beam, ix]], phidp[beam, ix[valids[beam, ix]]])[0]
+            kdp[beam, r] = linregress(x[ix][valids[beam, ix]],
+                                      phidp[beam, ix[valids[beam, ix]]])[0]
         # take care of the start and end of the beam
         #   start
         ix = np.arange(0, L)
         if np.sum(valids[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][valids[beam, ix]], phidp[beam, ix[valids[beam, ix]]])[0]
+            kdp[beam, ix] = linregress(x[ix][valids[beam, ix]],
+                                       phidp[beam, ix[valids[beam, ix]]])[0]
         # end
         ix = np.arange(shape[-1] - L, shape[-1])
         if np.sum(valids[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][valids[beam, ix]], phidp[beam, ix[valids[beam, ix]]])[0]
+            kdp[beam, ix] = linregress(x[ix][valids[beam, ix]],
+                                       phidp[beam, ix[valids[beam, ix]]])[0]
 
     # accounting for forward/backward propagation AND gate length
     return kdp.reshape(shape) / 2. / dr
 
 
 def kdp_from_phidp_sobel(phidp, L=7, dr=1.):
-    """Alternative Kdp from PhiDP by applying a sobel filter where possible and linear regression otherwise.
+    """Alternative :math:`K_{DP}` from :math:`Phi_{DP}` by applying a sobel
+    filter where possible and linear regression otherwise.
 
-    The results are quite similar to the moving window linear regression, but this
-    is much faster, depending on the percentage of NaN values in the bema, though.
-    The Sobel filter is applied everywhere but will return NaNs in case only
-    one value in the moving window is NaN. The remaining NaN values are then
-    dealt with by using local linear regression (see kdp_from_phidp_linregress).
+    The results are quite similar to the moving window linear regression, but
+    this is much faster, depending on the percentage of NaN values in the beam,
+    though. The Sobel filter is applied everywhere but will return NaNs in case
+    only one value in the moving window is NaN. The remaining NaN values are
+    then dealt with by using local linear regression
+    (see :meth:`~wradlib.dp.kdp_from_phidp_linregress`).
 
-    This Sobel filter solution has been provided by Scott Collis at:
+    This Sobel filter solution has been provided by Scott Collis at
+    StackOverflow :cite:`Sobel-linfit`
 
-    http://stackoverflow.com/questions/7288125/performing-a-moving-linear-fit-to-1d-data-in-python
-
-    Please note that the moving window size *L* is specified as the number of range
-    gates. Thus, this argument might need adjustment in case the range resolution changes.
-    In the original publication (Vulpiani :cite:`Vulpiani2012`), the value L=7 was chosen for
-    a range resolution of 1km.
+    Please note that the moving window size *L* is specified as the number of
+    range gates. Thus, this argument might need adjustment in case the range
+    resolution changes.
+    In the original publication (:cite:`Vulpiani2012`), the value L=7
+    was chosen for a range resolution of 1km.
 
     Warning
     -------
     The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension needs
-    to be the LAST dimension of the input array.
+    multiple dimensions in one step. For this purpose, the RANGE dimension
+    needs to be the LAST dimension of the input array.
 
     Parameters
     ----------
     phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the input array.
+        Note that the range dimension must be the last dimension of the
+        input array.
     L : integer
         Width of the window (as number of range gates)
     dr : gate length in km
@@ -351,14 +374,15 @@ def kdp_from_phidp_sobel(phidp, L=7, dr=1.):
     >>> gaps = np.concatenate([range(10, 20), range(30, 40), range(60, 80)])
     >>> phidp_raw[gaps] = np.nan
     >>> kdp_re = wradlib.dp.kdp_from_phidp_linregress(phidp_raw)
-    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")
-    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")
+    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")  # noqa
+    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")  # noqa
     >>> line3 = pl.plot(kdp_true, "g-", label="kdp_true")
-    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")
-    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))
+    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")  # noqa
+    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))  # noqa
 
     """
-    assert (L % 2) == 1, "Window size N for function kdp_from_phidp must be an odd number."
+    assert (L % 2) == 1, \
+        "Window size N for function kdp_from_phidp must be an odd number."
 
     shape = phidp.shape
     phidp = phidp.reshape((-1, shape[-1]))
@@ -390,16 +414,22 @@ def kdp_from_phidp_sobel(phidp, L=7, dr=1.):
             if np.sum(validphidp[beam, ix]) < L / 2:
                 # not enough valid values inside our window
                 continue
-            kdp[beam, r] = linregress(x[ix][validphidp[beam, ix]], phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, r] = linregress(x[ix][validphidp[beam, ix]],
+                                      phidp[beam,
+                                            ix[validphidp[beam, ix]]])[0]
         # take care of the start and end of the beam
         #   start
         ix = np.arange(0, L)
         if np.sum(validphidp[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][validphidp[beam, ix]], phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, ix] = linregress(x[ix][validphidp[beam, ix]],
+                                       phidp[beam,
+                                             ix[validphidp[beam, ix]]])[0]
         # end
         ix = np.arange(shape[-1] - L, shape[-1])
         if np.sum(validphidp[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][validphidp[beam, ix]], phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, ix] = linregress(x[ix][validphidp[beam, ix]],
+                                       phidp[beam,
+                                             ix[validphidp[beam, ix]]])[0]
 
     # accounting for forward/backward propagation AND gate length
     return kdp.reshape(shape) / 2. / dr
@@ -408,9 +438,7 @@ def kdp_from_phidp_sobel(phidp, L=7, dr=1.):
 def sobel(x, window_len=7):
     """Sobel differential filter for calculating KDP.
 
-    This solution has been taken from:
-
-    http://stackoverflow.com/questions/7288125/performing-a-moving-linear-fit-to-1d-data-in-python
+    This solution has been taken from StackOverflow :cite:`Sobel-linfit`
 
     Returns
     -------
@@ -421,36 +449,42 @@ def sobel(x, window_len=7):
     w = 2.0 * np.arange(window_len) / (window_len - 1.0) - 1.0
     w = w / (abs(w).sum())
     y = np.convolve(w, s, mode='valid')
-    return -1.0 * y[window_len / 2:len(x) + window_len / 2] / (window_len / 3.0)
+    return -1.0 * y[window_len / 2:len(x) +
+                    window_len / 2] / (window_len / 3.0)
 
 
 def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
-    """Alternative Kdp from PhiDP by applying a convolution filter where possible and linear regression otherwise.
+    """Alternative :math:`K_{DP}` from :math:`Phi_{DP}` by applying a
+    convolution filter where possible and linear regression otherwise.
 
-    The results are very similar to the moving window linear regression, but the convolution
-    is *much* faster, depending on the percentage of NaN values in the beam, though.
+    The results are very similar to the moving window linear regression, but
+    the convolution is *much* faster, depending on the percentage of NaN values
+    in the beam, though.
 
     The convolution filter was suggested by Kai Mühlbauer (University of Bonn).
 
-    The filter provides fast Kdp retrieval but will return NaNs in case at least
-    one value in the moving window is NaN. The remaining gates are treated by
-    using local linear regression where possible (see kdp_from_phidp_linregress).
+    The filter provides fast :math:`K_{DP}` retrieval but will return NaNs in
+    case at least one value in the moving window is NaN. The remaining gates
+    are treated by using local linear regression where possible
+    (see :meth:`~wradlib.dp.kdp_from_phidp_linregress`).
 
-    Please note that the moving window size *L* is specified as the number of range
-    gates. Thus, this argument might need adjustment in case the range resolution changes.
-    In the original publication (Vulpiani :cite:`Vulpiani2012`), the value L=7 was chosen for
-    a range resolution of 1km.
+    Please note that the moving window size *L* is specified as the number of
+    range gates. Thus, this argument might need adjustment in case the
+    range resolution changes.
+    In the original publication (:cite:`Vulpiani2012`), the value L=7
+    was chosen for a range resolution of 1km.
 
     Warning
     -------
     The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension needs
-    to be the LAST dimension of the input array.
+    multiple dimensions in one step. For this purpose, the RANGE dimension
+    needs to be the LAST dimension of the input array.
 
     Parameters
     ----------
     phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the input array.
+        Note that the range dimension must be the last dimension of the
+        input array.
     L : integer
         Width of the window (as number of range gates)
     dr : gate length in km
@@ -468,15 +502,16 @@ def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
     >>> gaps = np.concatenate([range(10, 20), range(30, 40), range(60, 80)])
     >>> phidp_raw[gaps] = np.nan
     >>> kdp_re = wradlib.dp.kdp_from_phidp_linregress(phidp_raw)
-    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")
-    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")
+    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")  # noqa
+    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")  # noqa
     >>> line3 = pl.plot(kdp_true, "g-", label="kdp_true")
-    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")
-    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))
+    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")  # noqa
+    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))  # noqa
     >>> pl.show()
 
     """
-    assert (L % 2) == 1, "Window size N for function kdp_from_phidp must be an odd number."
+    assert (L % 2) == 1, \
+        "Window size N for function kdp_from_phidp must be an odd number."
 
     shape = phidp.shape
     phidp = phidp.reshape((-1, shape[-1]))
@@ -507,21 +542,29 @@ def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
         nangates = np.where(invalidkdp[beam] & nvalid)[0]
         # now iterate over those
         for r in nangates:
-            ix = np.arange(max(0, r - int(L / 2)), min(r + int(L / 2) + 1, shape[-1]))
+            ix = np.arange(max(0, r - int(L / 2)),
+                           min(r + int(L / 2) + 1, shape[-1]))
             # check again (just to make sure...)
             if np.sum(validphidp[beam, ix]) < L / 2:
                 # not enough valid values inside our window
                 continue
-            kdp[beam, r] = linregress(x[ix][validphidp[beam, ix]], phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, r] = linregress(x[ix][validphidp[beam, ix]],
+                                      phidp[beam, ix[validphidp[beam, ix]]])[0]
         # take care of the start and end of the beam
         #   start
         ix = np.arange(0, L)
         if np.sum(validphidp[beam, ix]) >= 2:
-            kdp[beam, 0:(L / 2)] = linregress(x[ix][validphidp[beam, ix]], phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, 0:(L / 2)] = linregress(x[ix][validphidp[beam, ix]],
+                                              phidp[beam,
+                                                    ix[validphidp[beam,
+                                                                  ix]]])[0]
         # end
         ix = np.arange(shape[-1] - L, shape[-1])
         if np.sum(validphidp[beam, ix]) >= 2:
-            kdp[beam, -L / 2:] = linregress(x[ix][validphidp[beam, ix]], phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, -L / 2:] = linregress(x[ix][validphidp[beam,
+                                                             ix]],
+                                            phidp[beam,
+                                                  ix[validphidp[beam, ix]]])[0]
 
     # accounting for forward/backward propagation AND gate length
     return kdp.reshape(shape) / 2. / dr
@@ -529,13 +572,15 @@ def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
 
 def unfold_phi(phidp, rho, width=5, copy=False):
     """
-    Unfolds differential phase by adjusting values that exceeded maximum ambiguous range.
+    Unfolds differential phase by adjusting values that exceeded maximum
+    ambiguous range.
 
-    Accepts arbitrarily dimensioned arrays, but THE LAST DIMENSION MUST BE THE RANGE.
+    Accepts arbitrarily dimensioned arrays, but THE LAST DIMENSION MUST BE
+    THE RANGE.
 
     This is the fast Fortran-based implementation (RECOMMENDED).
 
-    The algorithm is based on the paper of Wang :cite:`Wang2009`.
+    The algorithm is based on the paper of :cite:`Wang2009`.
 
     Parameters
     ----------
@@ -565,8 +610,10 @@ def unfold_phi(phidp, rho, width=5, copy=False):
     for r in range(rs - 9):
         stdarr[..., r] = np.std(phidp[..., r:r + 9], -1)
 
-    phidp = speedup.f_unfold_phi(phidp=phidp.astype("f4"), rho=rho.astype("f4"),
-                                 gradphi=gradphi.astype("f4"), stdarr=stdarr.astype("f4"),
+    phidp = speedup.f_unfold_phi(phidp=phidp.astype("f4"),
+                                 rho=rho.astype("f4"),
+                                 gradphi=gradphi.astype("f4"),
+                                 stdarr=stdarr.astype("f4"),
                                  beams=beams, rs=rs, w=width)
 
     return phidp.reshape(shape)
@@ -574,13 +621,15 @@ def unfold_phi(phidp, rho, width=5, copy=False):
 
 def unfold_phi_naive(phidp, rho, width=5, copy=False):
     """
-    Unfolds differential phase by adjusting values that exceeded maximum ambiguous range.
+    Unfolds differential phase by adjusting values that exceeded maximum
+    ambiguous range.
 
-    Accepts arbitrarily dimensioned arrays, but THE LAST DIMENSION MUST BE THE RANGE.
+    Accepts arbitrarily dimensioned arrays, but THE LAST DIMENSION MUST BE
+    THE RANGE.
 
     This is the slow Python-based implementation (NOT RECOMMENDED).
 
-    The algorithm is based on the paper of Wang :cite:`Wang2009`.
+    The algorithm is based on the paper of :cite:`Wang2009`.
 
     Parameters
     ----------
@@ -608,7 +657,7 @@ def unfold_phi_naive(phidp, rho, width=5, copy=False):
     for r in range(rs - 9):
         stdarr[..., r] = np.std(phidp[..., r:r + 9], -1)
 
-    phi_corr = np.zeros(phidp.shape)
+    # phi_corr = np.zeros(phidp.shape)
     for beam in range(beams):
 
         if np.all(phidp[beam] == 0):
@@ -616,12 +665,15 @@ def unfold_phi_naive(phidp, rho, width=5, copy=False):
 
         # step 1: determine location where meaningful PhiDP profile begins
         for j in range(0, rs - width):
-            if (np.sum(stdarr[beam, j:j + width] < 5) == width) and (np.sum(rho[beam, j:j + 5] > 0.9) == width):
+            if (np.sum(stdarr[beam, j:j + width] < 5) == width) and \
+                    (np.sum(rho[beam, j:j + 5] > 0.9) == width):
                 break
 
         ref = np.mean(phidp[beam, j:j + width])
         for k in range(j + width, rs):
-            if np.sum(stdarr[beam, k - width:k] < 5) and np.logical_and(gradphi[beam, k] > -5, gradphi[beam, k] < 20):
+            if np.sum(stdarr[beam, k - width:k] < 5) and \
+                    np.logical_and(gradphi[beam, k] > -5,
+                                   gradphi[beam, k] < 20):
                 ref += gradphi[beam, k] * 0.5
                 if phidp[beam, k] - ref < -80:
                     if phidp[beam, k] < 0:
@@ -637,12 +689,14 @@ def linear_despeckle(data, N=3, copy=False):
 
     Warning
     -------
-    This function changes the original input array if argument copy is set to default (False).
+    This function changes the original input array if argument copy is set to
+    default (False).
 
     Parameters
     ----------
     data : multi-dimensional array
-        Note that the range dimension must be the last dimension of the input array.
+        Note that the range dimension must be the last dimension of the
+        input array.
 
     N : integer (must be either 3 or 5, 3 by default)
         Width of the window in which we check for speckle
@@ -651,7 +705,8 @@ def linear_despeckle(data, N=3, copy=False):
         If True, the input array will remain unchanged.
 
     """
-    assert N in (3, 5), "Window size N for function linear_despeckle must be 3 or 5."
+    assert N in (3, 5), \
+        "Window size N for function linear_despeckle must be 3 or 5."
     if copy:
         data = data.copy()
     axis = data.ndim - 1
@@ -677,12 +732,13 @@ def linear_despeckle(data, N=3, copy=False):
 def texture(data):
     """
     Compute the texture of the data by comparing values with a 3x3 neighborhood
-    (based on Gourley, 2007, :cite:`Gourley2007`).
+    (based on :cite:`Gourley2007`).
     NaN values in the original array have NaN textures.
 
     Parameters
     ----------
-    data : multi-dimensional array with shape (..., number of beams, number of range bins)
+    data : multi-dimensional array with shape (..., number of beams, number
+        of range bins)
 
     Returns
     ------
@@ -698,22 +754,26 @@ def texture(data):
     x7 = np.roll(x3, -1, -1)  # 9
     x8 = np.roll(x2, -1, -2)  # 7
 
-    xa = np.array([x1, x2, x3, x4, x5, x6, x7, x8])  # at least one NaN would give a sum of NaN
+    # at least one NaN would give a sum of NaN
+    xa = np.array([x1, x2, x3, x4, x5, x6, x7, x8])
 
     # get count of valid neighboring pixels
     xa_valid = np.ones(np.shape(xa))
     xa_valid[np.isnan(xa)] = 0
-    xa_valid_count = np.sum(xa_valid, axis=0)  # count number of valid neighbors
+    # count number of valid neighbors
+    xa_valid_count = np.sum(xa_valid, axis=0)
 
     num = np.zeros(data.shape)
     for xarr in xa:
         diff = data - xarr
-        # difference of NaNs will be converted to zero (to not affect the summation)
+        # difference of NaNs will be converted to zero
+        # (to not affect the summation)
         diff[np.isnan(diff)] = 0
         # only those with valid values are considered in the summation
         num += diff ** 2
 
-    num[np.isnan(data)] = np.nan  # reinforce that NaN values should have NaN textures
+    # reinforce that NaN values should have NaN textures
+    num[np.isnan(data)] = np.nan
 
     return np.sqrt(num / xa_valid_count)
 
@@ -721,9 +781,8 @@ def texture(data):
 def contiguous_regions(condition):
     """Finds contiguous True regions of the boolean array "condition".
 
-    This function was adopted from http://stackoverflow.com/questions/4494404/\
-    find-large-number-of-consecutive-values-fulfilling-condition-in-a-numpy-array
-    as proposed by Joe Kington in 2010.
+    This function was adopted from an StackOverflow answer as proposed
+    by Joe Kington in 2010 :cite:`Consecutive-values`.
 
     Parameters
     ----------
@@ -731,8 +790,8 @@ def contiguous_regions(condition):
 
     Returns
     -------
-    output : a 2D array where the first column is the start index of the region and the
-             second column is the end index.
+    output : a 2D array where the first column is the start index of the region
+        and the second column is the end index.
     """
 
     # Find the indices of changes in "condition"
