@@ -1,14 +1,6 @@
-# -------------------------------------------------------------------------------
-# Name:        ipol
-# Purpose:
-#
-# Authors:     Maik Heistermann, Stephan Jacobi and Thomas Pfaff
-#
-# Created:     26.10.2011
-# Copyright:   (c) Maik Heistermann, Stephan Jacobi and Thomas Pfaff 2011
-# Licence:     The MIT License
-# -------------------------------------------------------------------------------
 #!/usr/bin/env python
+# Copyright (c) 2016, wradlib developers.
+# Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
 Interpolation
@@ -17,7 +9,8 @@ Interpolation
 Interpolation allows to transfer data from one set of locations to another.
 This includes for example:
 
-- interpolating the data from a polar grid to a cartesian grid or irregular points
+- interpolating the data from a polar grid to a cartesian grid or irregular
+  points
 
 - interpolating point observations to a grid or a set of irregular points
 
@@ -48,6 +41,19 @@ from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import griddata
 import numpy as np
 import wradlib.util as util
+import warnings
+
+
+class MissingSourcesError(Exception):
+    """Is raised in case no source coordinates are available for interpolation.
+    """
+    pass
+
+
+class MissingTargetsError(Exception):
+    """Is raised in case no interpolation targets are available.
+    """
+    pass
 
 
 class IpolBase():
@@ -69,6 +75,8 @@ class IpolBase():
     def __init__(self, src, trg):
         src = self._make_coord_arrays(src)
         trg = self._make_coord_arrays(trg)
+        self.numsources = len(src)
+        self.numtargets = len(trg)
 
     def __call__(self, vals):
         """
@@ -96,8 +104,9 @@ class IpolBase():
         vals : ndarray of float
 
         """
-        assert len(vals) == self.numsources, 'Length of value array %d does not correspond to \
-        number of source points %d' % (len(vals), self.numsources)
+        assert len(vals) == self.numsources, \
+            ('Length of value array %d does not correspond to number '
+             'of source points %d' % (len(vals), self.numsources))
 
     def _make_coord_arrays(self, x):
         """
@@ -107,8 +116,8 @@ class IpolBase():
         Parameters
         ----------
         x : ndarray of float with shape (numpoints, ndim)
-            OR a sequence of ndarrays of float with len(sequence)==ndim and the length
-            of the ndarray corresponding to the number of points
+            OR a sequence of ndarrays of float with len(sequence)==ndim and
+            the length of the ndarray corresponding to the number of points
 
         """
         if type(x) in [list, tuple]:
@@ -161,9 +170,14 @@ class Nearest(IpolBase):
     trg : ndarray of floats, shape (npoints, ndims)
         Data point coordinates of the target points.
 
+    Examples
+    --------
+    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
+
+
     Note
     ----
-    Uses :func:`scipy.spatial.cKDTree`
+    Uses :class:`scipy:scipy.spatial.cKDTree`
 
     """
 
@@ -172,7 +186,11 @@ class Nearest(IpolBase):
         trg = self._make_coord_arrays(trg)
         # remember some things
         self.numtargets = len(trg)
+        if self.numtargets == 0:
+            raise MissingTargetsError
         self.numsources = len(src)
+        if self.numsources == 0:
+            raise MissingSourcesError
         # plant a tree
         self.tree = cKDTree(src)
         self.dists, self.ix = self.tree.query(trg, k=1)
@@ -196,7 +214,7 @@ class Nearest(IpolBase):
         """
         self._check_shape(vals)
         out = vals[self.ix]
-        if maxdist == None:
+        if maxdist is None:
             return out
         else:
             return np.where(self.dists > maxdist, np.nan, out)
@@ -217,9 +235,13 @@ class Idw(IpolBase):
     nnearest : integer - max. number of neighbours to be considered
     p : float - inverse distance power used in 1/dist**p
 
+    Examples
+    --------
+    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
+
     Note
     ----
-    Uses :func:`scipy.spatial.cKDTree`
+    Uses :class:`scipy:scipy.spatial.cKDTree`
 
     """
 
@@ -228,12 +250,25 @@ class Idw(IpolBase):
         trg = self._make_coord_arrays(trg)
         # remember some things
         self.numtargets = len(trg)
+        if self.numtargets == 0:
+            raise MissingTargetsError
         self.numsources = len(src)
-        self.nnearest = nnearest
+        if self.numsources == 0:
+            raise MissingSourcesError
+        if nnearest > self.numsources:
+            warnings.warn(
+                "wradlib.ipol.Idw: <nnearest> is larger than number of "
+                "source points and is set to %d corresponding to the "
+                "number of source points." % self.numsources,
+                UserWarning
+            )
+            self.nnearest = self.numsources
+        else:
+            self.nnearest = nnearest
         self.p = p
         # plant a tree
         self.tree = cKDTree(src)
-        self.dists, self.ix = self.tree.query(trg, k=nnearest)
+        self.dists, self.ix = self.tree.query(trg, k=self.nnearest)
         # avoid bug, if there is only one neighbor at all
         if self.dists.ndim == 1:
             self.dists = self.dists[:, np.newaxis]
@@ -257,10 +292,13 @@ class Idw(IpolBase):
 
         """
 
-        # self distances: a list of arrays of distances of the nearest points which are indicated by self.ix
+        # self distances: a list of arrays of distances of the nearest points
+        # which are indicated by self.ix
+        self._check_shape(vals)
         outshape = list(vals.shape)
         outshape[0] = len(self.dists)
-        interpol = np.repeat(np.nan, util._shape2size(outshape)).reshape(tuple(outshape)).astype('f4')
+        interpol = (np.repeat(np.nan, util._shape2size(outshape)).
+                    reshape(tuple(outshape)).astype('f4'))
         # weights is the container for the weights (a list)
         weights = list(range(len(self.dists)))
         # sources is the container for the source point indices
@@ -288,12 +326,13 @@ class Idw(IpolBase):
             weights[jinterpol] = w
             src_ix[jinterpol] = ix
             jinterpol += 1
-        return interpol  ## if self.qdim > 1  else interpol[0]
+        return interpol  # if self.qdim > 1  else interpol[0]
 
 
 class Linear(IpolBase):
     """
-    Interface to the scipy.interpolate.LinearNDInterpolator class.
+    Interface to the :class:`scipy:scipy.interpolate.LinearNDInterpolator`
+    class.
 
     We provide this class in order to achieve a uniform interface for all
     Interpolator classes
@@ -304,6 +343,10 @@ class Linear(IpolBase):
         Data point coordinates of the source points.
     trg : ndarray of floats, shape (npoints, ndims)
         Data point coordinates of the target points.
+
+    Examples
+    --------
+    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
     """
 
     def __init__(self, src, trg):
@@ -311,7 +354,11 @@ class Linear(IpolBase):
         self.trg = self._make_coord_arrays(trg)
         # remember some things
         self.numtargets = len(trg)
+        if self.numtargets == 0:
+            raise MissingTargetsError
         self.numsources = len(src)
+        if self.numsources == 0:
+            raise MissingSourcesError
 
     def __call__(self, vals, fill_value=np.nan):
         """
@@ -334,9 +381,9 @@ class Linear(IpolBase):
         return ip(self.trg)
 
 
-# -------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Covariance routines needed for Kriging
-# -------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 def parse_covariogram(cov_model):
     """"""
     patterns = [re.compile('([\d\.]+) Nug\(([\d\.]+)\)'),  # nugget
@@ -346,7 +393,8 @@ def parse_covariogram(cov_model):
                 re.compile('([\d\.]+) Gau\(([\d\.]+)\)'),  # gaussian
                 re.compile('([\d\.]+) Mat\(([\d\.]+)\)\^([\d\.]+)'),  # matern
                 re.compile('([\d\.]+) Pow\(([\d\.]+)\)'),  # power
-                re.compile('([\d\.]+) Cau\(([\d\.]+)\)\^([\d\.]+)\^([\d\.]+)'),  # cauchy
+                # cauchy
+                re.compile('([\d\.]+) Cau\(([\d\.]+)\)\^([\d\.]+)\^([\d\.]+)'),
                 ]
 
     cov_funs = [cov_nug,
@@ -399,7 +447,9 @@ def cov_exp(h, sill=1.0, rng=1.0):
 def cov_sph(h, sill=1.0, rng=1.0):
     """spherical type covariance function"""
     h = np.asanyarray(h)
-    return np.where(h < rng, sill * (1. - 1.5 * h / rng + h ** 3 / (2 * rng ** 3)), 0.)
+    return np.where(h < rng, sill * (1. - 1.5 * h /
+                                     rng + h ** 3 /
+                                     (2 * rng ** 3)), 0.)
 
 
 def cov_gau(h, sill=1.0, rng=1.0):
@@ -426,13 +476,16 @@ def cov_mat(h, sill=1.0, rng=1.0, shp=0.5):
     if shp > 100:
         c = cov_gau(h, sill, rng)
     else:
-        Kv = scipy.special.kv  # modified bessel function of second kind of order v
-        Tau = scipy.special.gamma  # Gamma function
+        # modified bessel function of second kind of order v
+        Kv = scipy.special.kv
+        # Gamma function
+        Tau = scipy.special.gamma
 
         fac1 = h / rng * 2.0 * np.sqrt(shp)
         fac2 = (Tau(shp) * 2.0 ** (shp - 1.0))
 
-        c = np.where(h != 0, sill * 1.0 / fac2 * fac1 ** shp * Kv(shp, fac1), sill)
+        c = np.where(h != 0, sill * 1.0 /
+                     fac2 * fac1 ** shp * Kv(shp, fac1), sill)
 
     return c
 
@@ -465,26 +518,26 @@ class OrdinaryKriging(IpolBase):
     combinations.
     Each basic covariogram is usually defined by
     Note that, strictly speaking, this implementation doesn't allow Kriging of
-    fields for which the covariance does not exist. While this is mathematically
-    possible, it is rather rare for fields encountered in reality. Therefore,
-    this should not be a severe limitation.
+    fields for which the covariance does not exist. While this is
+    mathematically possible, it is rather rare for fields encountered in
+    reality. Therefore, this should not be a severe limitation.
 
     Most (co-)variograms are characterized by a sill parameter (which is
     the (co-)variance at separation distance 0) a range parameter (which
     indicates a separation distance after which the the covariance drops
     close to zero) an sometimes additional parameters governing the shape
-    of the function. In the following range is given by the variable `r` and the
-    sill by the variable `s`.
+    of the function. In the following range is given by the variable `r` and
+    the sill by the variable `s`.
     Currently implemented are:
 
-    - Pure Nugget
-    - Exponential
-    - Spherical
-    - Gaussian
-    - Linear
-    - Matern
-    - Power
-    - Cauchy
+        - Pure Nugget
+        - Exponential
+        - Spherical
+        - Gaussian
+        - Linear
+        - Matern
+        - Power
+        - Cauchy
 
     Parameters
     ----------
@@ -510,6 +563,9 @@ class OrdinaryKriging(IpolBase):
     After initialization the estimation variance at each interpolation target
     may be retrieved from the attribute `estimation_variance`.
 
+    Examples
+    --------
+    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
     """
 
     def __init__(self, src, trg, cov='1.0 Exp(10000.)', nnearest=12):
@@ -518,11 +574,25 @@ class OrdinaryKriging(IpolBase):
         self.trg = self._make_coord_arrays(trg)
         # remember some things
         self.numtargets = len(trg)
+        if self.numtargets == 0:
+            raise MissingTargetsError
         self.numsources = len(src)
-        self.nnearest = nnearest
+        if self.numsources == 0:
+            raise MissingSourcesError
+        if nnearest > self.numsources:
+            warnings.warn(
+                "wradlib.ipol.OrdinaryKriging: <nnearest> is "
+                "larger than number of source points and is "
+                "set to %d corresponding to the "
+                "number of source points." % self.numsources,
+                UserWarning
+            )
+            self.nnearest = self.numsources
+        else:
+            self.nnearest = nnearest
         # plant a tree
         self.tree = cKDTree(src)
-        self.dists, self.ix = self.tree.query(trg, k=min(nnearest, self.numsources))
+        self.dists, self.ix = self.tree.query(trg, k=self.nnearest)
         # avoid bug, if there is only one neighbor at all
         if self.dists.ndim == 1:
             self.dists = self.dists[:, np.newaxis]
@@ -564,8 +634,8 @@ class OrdinaryKriging(IpolBase):
             rhs = self._krig_rhs(dist)
             weights = np.linalg.solve(matrix, rhs)
             self.weights.append(weights)
-            self.estimation_variance.append(self.cov_func(0.)
-                                            - np.sum(weights * rhs))
+            self.estimation_variance.append(self.cov_func(0.) -
+                                            np.sum(weights * rhs))
 
     def __call__(self, vals):
         """
@@ -589,7 +659,8 @@ class OrdinaryKriging(IpolBase):
         self._check_shape(v)
         # calculate estimator
         weights = np.array(self.weights)
-        ip = np.add.reduce(weights[:, :-1, np.newaxis] * v[self.ix, ...], axis=1)
+        ip = np.add.reduce(weights[:, :-1, np.newaxis] * v[self.ix, ...],
+                           axis=1)
 
         return ip
 
@@ -644,11 +715,25 @@ class ExternalDriftKriging(IpolBase):
         self.trg_drift = trg_drift
         # remember some things
         self.numtargets = len(trg)
+        if self.numtargets == 0:
+            raise MissingTargetsError
         self.numsources = len(src)
-        self.nnearest = nnearest
+        if self.numsources == 0:
+            raise MissingSourcesError
+        if nnearest > self.numsources:
+            warnings.warn(
+                "wradlib.ipol.ExternalDriftKriging: <nnearest> is larger "
+                "than number of source points and is set to %d "
+                "corresponding to the number of source "
+                "points." % self.numsources,
+                UserWarning
+            )
+            self.nnearest = self.numsources
+        else:
+            self.nnearest = nnearest
         # plant a tree
         self.tree = cKDTree(src)
-        self.dists, self.ix = self.tree.query(trg, k=min(nnearest, self.numsources))
+        self.dists, self.ix = self.tree.query(trg, k=self.nnearest)
         # avoid bug, if there is only one neighbor at all
         if self.dists.ndim == 1:
             self.dists = self.dists[:, np.newaxis]
@@ -702,8 +787,8 @@ class ExternalDriftKriging(IpolBase):
             except np.linalg.LinAlgError:
                 weights = np.repeat(np.nan, len(rhs))
             all_weights.append(weights)
-            estimation_variances.append(self.cov_func(0.)
-                                        - np.sum(weights * rhs))
+            estimation_variances.append(self.cov_func(0.) -
+                                        np.sum(weights * rhs))
 
         return all_weights, estimation_variances
 
@@ -732,14 +817,16 @@ class ExternalDriftKriging(IpolBase):
         if src_drift is None:
             # check if we have data from __init__
             if self.src_drift is None:
-                raise ValueError('src_drift must be specified either on ' \
-                                 + 'initialization or when calling the interpolator.')
+                raise ValueError('src_drift must be specified either on '
+                                 'initialization or when calling '
+                                 'the interpolator.')
             src_drift = self.src_drift
         if trg_drift is None:
             # check if we have data from __init__
             if self.trg_drift is None:
-                raise ValueError('trg_drift must be specified either on ' \
-                                 + 'initialization or when calling the interpolator.')
+                raise ValueError('trg_drift must be specified either on '
+                                 'initialization or when calling the '
+                                 'interpolator.')
             trg_drift = self.trg_drift
 
         src_d = self._make_2d(src_drift)
@@ -758,51 +845,55 @@ class ExternalDriftKriging(IpolBase):
             self.weights = wght
             self.estimation_variance = variances
             weights = np.array(self.weights)
-            ip = np.add.reduce(weights[:, :-2, np.newaxis] * v[self.ix, ...], axis=1)
+            ip = np.add.reduce(weights[:, :-2, np.newaxis] * v[self.ix, ...],
+                               axis=1)
         # otherwise we need to setup and solve the kriging system for each
         # field individually
         else:
             ip = np.empty((self.trg.shape[0], v.shape[1]))
-            assert (v.shape[1] == src_d.shape[1]) and (v.shape[1] == trg_d.shape[1])
+            assert ((v.shape[1] == src_d.shape[1]) and
+                    (v.shape[1] == trg_d.shape[1]))
             for i in range(v.shape[1]):
                 wght, variances = self._krige(src_d[:, i].squeeze(),
                                               trg_d[:, i].squeeze())
 
                 weights = np.array(wght)
-                ip[:, i] = np.add.reduce(weights[:, :-2] * v[self.ix, i], axis=1)
+                ip[:, i] = np.add.reduce(weights[:, :-2] * v[self.ix, i],
+                                         axis=1)
                 self.weights.append(weights)
                 self.estimation_variance.append(variances)
 
         return ip
 
 
-# -------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Wrapper functions
-# -------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
     """
     Convenience function to use the interpolation classes in an efficient way
 
-    The interpolation classes in wradlib.ipol are computationally very efficient
-    if they are applied on large multi-dimensional arrays of which the first dimension
-    must be the locations' dimension (1d or 2d coordinates) and the following dimensions
-    can be anything (e.g. time or ensembles). This way, the weights need to be computed
-    only once. However, this can only be done with success if all source values for
-    the interpolation are valid numbers. If the source values contain let's say
-    *np.nan* types, the result of the interpolation will be *np.nan* in the
-    vicinity of the corresponding points, too. Imagine that you have a time series
-    of observations at points and in each time step one observation is missing.
+    The interpolation classes in wradlib.ipol are computationally very
+    efficient if they are applied on large multi-dimensional arrays of which
+    the first dimension must be the locations' dimension (1d or 2d coordinates)
+    and the following dimensions can be anything (e.g. time or ensembles). This
+    way, the weights need to be computed only once. However, this can only be
+    done with success if all source values for the interpolation are valid
+    numbers. If the source values contain let's say *np.nan* types, the result
+    of the interpolation will be *np.nan* in the vicinity of the corresponding
+    points, too. Imagine that you have a time series of observations at points
+    and in each time step one observation is missing.
     You would still like to efficiently apply the interpolation
     classes, but you will need to account for the resulting *np.nan* values in
     the interpolation output.
 
-    In order to still allow for the efficient application, you have to take care
-    of the remaining np.nan in your interpolation result. This is done by this
-    convenience function.
+    In order to still allow for the efficient application, you have to take
+    care of the remaining np.nan in your interpolation result. This is done by
+    this convenience function.
 
-    Alternatively, you have to make sure that your *vals* argument does not contain
-    any *np.nan* values OR you have to post-process missing values in your interpolation
-    result in another way.
+    Alternatively, you have to make sure that your *vals* argument does not
+    contain any *np.nan* values OR you have to post-process missing values in
+    your interpolation result in another way.
 
     Warning
     -------
@@ -842,7 +933,8 @@ def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
 
     """
     if vals.ndim == 1:
-        # source values are one dimensional, we have just to remove invalid data
+        # source values are one dimensional, we have just
+        # to remove invalid data
         ix_valid = np.where(np.isfinite(vals))[0]
         ip = Interpolator(src[ix_valid], trg, *args, **kwargs)
         result = ip(vals[ix_valid])
@@ -851,19 +943,25 @@ def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
         ip = Interpolator(src, trg, *args, **kwargs)
         result = ip(vals)
         nan_in_result = np.where(np.isnan(result))
-        nan_in_vals = np.where(np.isnan(vals))
+        # nan_in_vals = np.where(np.isnan(vals))
         for i in np.unique(nan_in_result[-1]):
             ix_good = np.where(np.isfinite(vals[..., i]))[0]
-            ix_broken_targets = nan_in_result[0][np.where(nan_in_result[-1] == i)[0]]
-            ip = Interpolator(src[ix_good], trg[nan_in_result[0][np.where(nan_in_result[-1] == i)[0]]], *args, **kwargs)
+            ix_broken_targets = (nan_in_result[0]
+                                 [np.where(nan_in_result[-1] == i)[0]])
+            ip = Interpolator(src[ix_good],
+                              trg[nan_in_result[0]
+                              [np.where(nan_in_result[-1] == i)[0]]],
+                              *args, **kwargs)
             tmp = ip(vals[ix_good, i].reshape((len(ix_good), -1)))
             result[ix_broken_targets, i] = tmp.ravel()
     else:
         if not np.any(np.isnan(vals.ravel())):
             raise Exception(
-                'At the moment, <interpolate> can only deal with NaN values in <vals> if vals has less than 3 dimension.')
+                'At the moment, <interpolate> can only deal with NaN values '
+                'in <vals> if vals has less than 3 dimension.')
         else:
-            # if no NaN value are in <vals> we can safely apply the Interpolator as is
+            # if no NaN value are in <vals> we can safely apply the
+            # Interpolator as is
             ip = Interpolator(src, trg, *args, **kwargs)
             result = ip(vals[ix_valid])
     return result
@@ -892,17 +990,17 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
 
     Examples
     --------
-    >>> import numpy as np
+    >>> import numpy as np  # noqa
     >>> import wradlib as wrl
     >>> # creating a data array and mask some values
     >>> data = np.arange(12.).reshape(4,3)
     >>> masked_values = (data==2) | (data==9)
     >>> # interpolate the masked data based on ''masked_values''
-    >>> filled_a = wrl.ipol.interpolate_polar(data, mask = masked_values, Interpolator = wrl.ipol.Linear)
+    >>> filled_a = wrl.ipol.interpolate_polar(data, mask = masked_values, Interpolator = wrl.ipol.Linear)  # noqa
     >>> ax, pm = wrl.vis.plot_ppi(filled_a)
-    >>> # the same result can be achieved by using an masked array instead of an explicit mask
+    >>> # the same result can be achieved by using an masked array instead of an explicit mask  # noqa
     >>> mdata = np.ma.array(data, mask = masked_values)
-    >>> filled_b = wrl.ipol.interpolate_polar(mdata, Interpolator = wrl.ipol.Linear)
+    >>> filled_b = wrl.ipol.interpolate_polar(mdata, Interpolator = wrl.ipol.Linear)  # noqa
     >>> ax, pm = wrl.vis.plot_ppi(filled_b)
 
 
@@ -910,7 +1008,8 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
     if mask is None:
         # no mask assigned: try to get it from masked array
         if type(data) != np.ma.core.MaskedArray:
-            print('Warning! Neither an explicit mask is assigned nor the data-array is masked.')
+            print('Warning! Neither an explicit mask is assigned nor the '
+                  'data-array is masked.')
         mask = np.ma.getmaskarray(data)
     elif not np.any(mask):
         # mask contains no True values, so there is nothing to fill
@@ -919,14 +1018,17 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
     # construct the ranges for every bin
     ranges = np.tile(np.arange(0.5, data.shape[1] + 0.5), data.shape[0])
     # construct the angles for every bin
-    angles = np.repeat(np.radians(np.arange(0, 360, 360. / data.shape[0])), data.shape[1])
+    angles = np.repeat(np.radians(np.arange(0, 360, 360. / data.shape[0])),
+                       data.shape[1])
     # calculate cartesian coordinates for every bin
     binx = np.cos(angles) * ranges
     biny = np.sin(angles) * ranges
     # calculate cartesian coordinates for bins, which are not masked
-    src_coord = np.array([(np.delete(binx, clutter_indices)), (np.delete(biny, clutter_indices))]).transpose()
+    src_coord = np.array([(np.delete(binx, clutter_indices)),
+                          (np.delete(biny, clutter_indices))]).transpose()
     # calculate cartesian coordinates for bins, which are masked
-    trg_coord = np.array([binx[clutter_indices], biny[clutter_indices]]).transpose()
+    trg_coord = np.array([binx[clutter_indices],
+                          biny[clutter_indices]]).transpose()
     # data values for bins, which are not masked
     values_list = np.delete(data, clutter_indices)
     filled_data = data.copy().ravel()
@@ -934,11 +1036,14 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
     filling = interpolate(src_coord, trg_coord, values_list, Interpolator)
     # fill data with the interpolations
     filled_data[clutter_indices] = filling.astype(filled_data.dtype)
-    # in case of nans as processed at the rim when interpolating linear, these values are finally interpolated
-    # by nearest Neighbor interpolation
+    # in case of nans as processed at the rim when interpolating linear,
+    # these values are finally interpolated by nearest Neighbor interpolation
     if np.any(np.isnan(filled_data)):
-        trg_coord = np.array([binx[np.where(np.isnan(filled_data))], biny[np.where(np.isnan(filled_data))]]).transpose()
-        filling = interpolate(src_coord, trg_coord, values_list, Interpolator=Nearest)
+        trg_coord = (np.array([binx[np.where(np.isnan(filled_data))],
+                              biny[np.where(np.isnan(filled_data))]])
+                     .transpose())
+        filling = interpolate(src_coord, trg_coord, values_list,
+                              Interpolator=Nearest)
         filled_data[np.where(np.isnan(filled_data))] = filling
     return filled_data.reshape(data.shape[0], data.shape[1])
 
@@ -995,7 +1100,7 @@ def cart2irregular_spline(cartgrid, values, newgrid, **kwargs):
     .. versionadded:: 0.6.0
 
     Keyword arguments are fed through to
-    :func:`scipy:scipy.ndimage.interpolation.map_coordinates`
+    :func:`scipy:scipy.ndimage.map_coordinates`
 
     Parameters
     ----------
@@ -1005,12 +1110,17 @@ def cart2irregular_spline(cartgrid, values, newgrid, **kwargs):
         2 dimensional array (nx, ny) of data values
     newgrid : numpy ndarray
         Nx2 dimensional array (..., lon/lat) of floats
-    kwargs : :func:`scipy:scipy.ndimage.interpolation.map_coordinates`
+    kwargs : :func:`scipy:scipy.ndimage.map_coordinates`
 
     Returns
     -------
     interp : numpy ndarray
         array with interpolated values of size N
+
+    Examples
+    --------
+    See :ref:`notebooks/beamblockage/wradlib_beamblock.ipynb#\
+Read-DEM-Raster-Data`.
     """
 
     # TODO: dimension checking
