@@ -1,14 +1,6 @@
-# -------------------------------------------------------------------------------
-# Name:        qual
-# Purpose:
-#
-# Authors:     Maik Heistermann, Stephan Jacobi and Thomas Pfaff
-#
-# Created:     26.10.2011
-# Copyright:   (c) Maik Heistermann, Stephan Jacobi and Thomas Pfaff 2011
-# Licence:     The MIT License
-# -------------------------------------------------------------------------------
 #!/usr/bin/env python
+# Copyright (c) 2016, wradlib developers.
+# Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
 Data Quality
@@ -44,7 +36,7 @@ import numpy as np
 def beam_height_ft(ranges, elevations, degrees=True, re=6371000):
     """Calculates the height of a radar beam above the antenna according to
     the 4/3 (four-thirds -> ft) effective Earth radius model.
-    The formula was taken from Collier :cite:`Collier1996`.
+    The formula was taken from :cite:`Collier1996`.
 
     Parameters
     ----------
@@ -68,7 +60,8 @@ def beam_height_ft(ranges, elevations, degrees=True, re=6371000):
     ----
     The shape of `elevations` and `ranges` may differ in which case numpy's
     broadcasting rules will apply and the shape of `output` will be that of
-    the broadcast arrays. See the numpy documentation on how broadcasting works.
+    the broadcast arrays. See the numpy documentation on how broadcasting
+    works.
 
     """
     if degrees:
@@ -76,13 +69,14 @@ def beam_height_ft(ranges, elevations, degrees=True, re=6371000):
     else:
         elev = elevations
 
-    return ((ranges ** 2 * np.cos(elev) ** 2) / (2 * (4. / 3.) * re)) + ranges * np.sin(elev)
+    return ((ranges ** 2 * np.cos(elev) ** 2) /
+            (2 * (4. / 3.) * re)) + ranges * np.sin(elev)
 
 
 def beam_height_ft_doviak(ranges, elevations, degrees=True, re=6371000):
-    """Calculates the height of a radar beam above the antenna according to \
+    """Calculates the height of a radar beam above the antenna according to
     the 4/3 (four-thirds -> ft) effective Earth radius model.
-    The formula was taken from Doviak :cite:`Doviak1993`.
+    The formula was taken from :cite:`Doviak1993`.
 
     Parameters
     ----------
@@ -107,7 +101,8 @@ def beam_height_ft_doviak(ranges, elevations, degrees=True, re=6371000):
     ----
     The shape of `elevations` and `ranges` may differ in which case numpy's
     broadcasting rules will apply and the shape of `output` will be that of
-    the broadcast arrays. See the numpy documentation on how broadcasting works.
+    the broadcast arrays. See the numpy documentation on how broadcasting
+    works.
 
     """
     if degrees:
@@ -117,18 +112,21 @@ def beam_height_ft_doviak(ranges, elevations, degrees=True, re=6371000):
 
     reft = (4. / 3.) * re
 
-    return np.sqrt(ranges ** 2 + reft ** 2 + 2 * ranges * reft * np.sin(elev)) - reft
+    return np.sqrt(ranges ** 2 + reft ** 2 +
+                   2 * ranges * reft * np.sin(elev)) - reft
 
 
 def pulse_volume(ranges, h, theta):
-    """Calculates the sampling volume of the radar beam per bin depending on \
+    r"""Calculates the sampling volume of the radar beam per bin depending on
     range and aperture.
 
-    We assume a cone frustum which has the volume V=(pi/3)*h*(R**2 + R*r + r**2).
+    We assume a cone frustum which has the volume
+    :math:`V=(\pi/3) \cdot h \cdot (R^2 + R \cdot r + r^2)`.
     R and r are the radii of the two frustum surface circles. Assuming that the
-    pulse width is small compared to the range, we get R=r=tan(theta*pi/180)*range.
-    Thus, the pulse volume simpy becomes a the volume of a cylinder with
-    V=pi * h * range**2 * tan(theta*pi/180)**2
+    pulse width is small compared to the range, we get
+    :math:`R=r= \tan ( \theta \cdot \pi/180 ) \cdot range`.
+    Thus, the pulse volume simply becomes the volume of a cylinder with
+    :math:`V=\pi \cdot h \cdot range^2 \cdot \tan(\theta \cdot \pi/180)^2`
 
     Parameters
     ----------
@@ -142,7 +140,12 @@ def pulse_volume(ranges, h, theta):
     Returns
     -------
     output : array
-        volume of radar bins at each range in `ranges` [m**3]
+        volume of radar bins at each range in `ranges` [:math:`m^3`]
+
+    Examples
+    --------
+
+    See :ref:`notebooks/workflow/recipe1.ipynb`.
 
     """
     return np.pi * h * (ranges ** 2) * (np.tan(np.radians(theta))) ** 2
@@ -180,6 +183,8 @@ def beam_block_frac(Th, Bh, a):
     --------
     >>> PBB = beam_block_frac(Th,Bh,a) #doctest: +SKIP
 
+    See :ref:`notebooks/beamblockage/wradlib_beamblock.ipynb`.
+
     Note
     ----
     This procedure uses a simplified interception function where no vertical
@@ -196,7 +201,8 @@ def beam_block_frac(Th, Bh, a):
     # radar beam (Bech et al. (2003), Fig.3)
     y = Th - Bh
 
-    Numer = (y * np.sqrt(a ** 2 - y ** 2)) + (a ** 2 * np.arcsin(y / a)) + (np.pi * a ** 2 / 2.)
+    Numer = (y * np.sqrt(a ** 2 - y ** 2)) + \
+            (a ** 2 * np.arcsin(y / a)) + (np.pi * a ** 2 / 2.)
 
     Denom = np.pi * a ** 2
 
