@@ -1,14 +1,7 @@
-# -------------------------------------------------------------------------------
-# Name:        trafo
-# Purpose:
-#
-# Authors:     Maik Heistermann, Stephan Jacobi and Thomas Pfaff
-#
-# Created:     26.10.2011
-# Copyright:   (c) Maik Heistermann, Stephan Jacobi and Thomas Pfaff 2011
-# Licence:     The MIT License
-# -------------------------------------------------------------------------------
 #!/usr/bin/env python
+# Copyright (c) 2016, wradlib developers.
+# Distributed under the MIT License. See LICENSE.txt for more info.
+
 """
 Data Transformation
 ^^^^^^^^^^^^^^^^^^^
@@ -37,7 +30,6 @@ to dBZ-values to Z-values and vice versa.
 """
 import numpy as np
 
-
 # CONSTANTS
 meters_per_mile = 1609.344
 meters_per_nautical_mile = 1852.
@@ -51,32 +43,52 @@ def rvp2dBZ(x):
     ----------
     x : int
         a number or an array
+
+    Examples
+    --------
+    >>> from wradlib.trafo import rvp2dBZ
+    >>> print(rvp2dBZ(65.))
+    0.0
     """
-    return x*0.5-32.5
+    return x * 0.5 - 32.5
 
 
 def decibel(x):
     """Calculates the decibel representation of the input values
-    dBZ = 10*log10(z)
+
+    :math:`dBZ=10 \cdot \log_{10} z`
 
     Parameters
     ----------
     x : a number or an array
         (must not be <= 0.)
 
+    Examples
+    --------
+    >>> from wradlib.trafo import decibel
+    >>> print(decibel(100.))
+    20.0
     """
-    return 10.*np.log10(x)
+    return 10. * np.log10(x)
 
 
 def idecibel(x):
     """Calculates the inverse of input decibel values
-    10.**(x/10.)
+
+    :math:`z=10^{x \over 10}`
 
     Parameters
     ----------
     x : a number or an array
+
+    Examples
+    --------
+    >>> from wradlib.trafo import idecibel
+    >>> print(idecibel(10.))
+    10.0
+
     """
-    return 10.**(x/10.)
+    return 10. ** (x / 10.)
 
 
 def r2depth(x, interval):
@@ -104,12 +116,14 @@ def r2depth(x, interval):
 def kdp2r(kdp, f, a=129., b=0.85):
     """Estimating rainfall intensity directly from specific differential phase.
 
-    The general power law expression has been suggested by Ryzhkov et al. :cite:`Ryzhkov2005`.
+    The general power law expression has been suggested by :cite:`Ryzhkov2005`.
 
-    The default parameters have been set according to Bringi and Chandrasekar :cite:`Bringi2001`.
+    The default parameters have been set according to :cite:`Bringi2001`.
 
-    **Please note that this way, rainfall intensities can become negative.** This is
-    an intended behaviour in order to account for noisy Kdp values.
+    Note
+    ----
+    **Please note that this way, rainfall intensities can become negative.**
+    This is an intended behaviour in order to account for noisy Kdp values.
 
     Parameters
     ----------
@@ -132,30 +146,30 @@ def kdp2r(kdp, f, a=129., b=0.85):
     output : array
         array of rainfall intensity
     """
-    return np.sign(kdp) * a * (np.abs(kdp) / f)**b
+    return np.sign(kdp) * a * (np.abs(kdp) / f) ** b
 
 
 def si2kmh(vals):
     """Conversion from SI wind speed units to km/hr.
-    
+
     .. versionadded:: 0.6.0
-    
+
     Note
     ----
     Code was migrated from https://github.com/nguy/PyRadarMet.
-    
+
     Parameters
     ----------
     vals : float
         float or array of floats
         Speed in SI units (m/s)
- 
+
     Returns
     -------
     output: float
         float or array of floats
         Speed in km/hr
-    
+
     Examples
     --------
     >>> from wradlib.trafo import si2kmh
@@ -179,13 +193,13 @@ def si2mph(vals):
     vals : float
         float or array of floats
         Speed in SI units (m/s)
- 
+
     Returns
     -------
     output: float
         float or array of floats
         Speed in miles per hour
-    
+
     Examples
     --------
     >>> from wradlib.trafo import si2mph
@@ -194,7 +208,7 @@ def si2mph(vals):
 
     """
     return vals * 3600. / meters_per_mile
-    
+
 
 def si2kts(vals):
     """Conversion from SI wind speed units to knots
@@ -210,13 +224,13 @@ def si2kts(vals):
     vals : float
         float or array of floats
         Speed in SI units (m/s)
- 
+
     Returns
     -------
     output: float
         float or array of floats
         Speed in knots
-    
+
     Examples
     --------
     >>> from wradlib.trafo import si2kts
@@ -225,7 +239,7 @@ def si2kts(vals):
 
     """
     return vals * 3600. / meters_per_nautical_mile
-    
+
 
 def kmh2si(vals):
     """Conversion from km/hr to SI wind speed units
@@ -235,19 +249,19 @@ def kmh2si(vals):
     Note
     ----
     Code was migrated from https://github.com/nguy/PyRadarMet.
-    
+
     Parameters
     ----------
     vals: float
         float or array of floats
         Wind speed in km/hr
- 
+
     Returns
     -------
     output: float
         float or array of floats
         Wind speed in SI units (m/s)
-    
+
     Examples
     --------
     >>> from wradlib.trafo import kmh2si
@@ -266,19 +280,19 @@ def mph2si(vals):
     Note
     ----
     Code was migrated from https://github.com/nguy/PyRadarMet.
-    
+
     Parameters
     ----------
     vals: float
         float or array of floats
         Wind speed in miles per hour
- 
+
     Returns
     -------
     output: float
         float or array of floats
         Wind speed in SI units (m/s)
-    
+
     Examples
     --------
     >>> from wradlib.trafo import mph2si
@@ -297,19 +311,19 @@ def kts2si(vals):
     Note
     ----
     Code was migrated from https://github.com/nguy/PyRadarMet.
-    
+
     Parameters
     ----------
     vals: float
         float or array of floats
         Wind speed in knots
- 
+
     Returns
     -------
     output: float
         float or array of floats
         Wind speed in SI units (m/s)
-    
+
     Examples
     --------
     >>> from wradlib.trafo import kts2si
@@ -322,4 +336,3 @@ def kts2si(vals):
 
 if __name__ == '__main__':
     print('wradlib: Calling module <trafo> as main...')
-
