@@ -1,15 +1,7 @@
-# -*- coding: utf-8 -*-
-# -------------------------------------------------------------------------------
-# Name:        vis
-# Purpose:
-#
-# Authors:     Maik Heistermann, Stephan Jacobi and Thomas Pfaff
-#
-# Created:     26.10.2011
-# Copyright:   (c) Maik Heistermann, Stephan Jacobi and Thomas Pfaff 2011
-# Licence:     The MIT License
-# -------------------------------------------------------------------------------
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
+# Copyright (c) 2016, wradlib developers.
+# Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
 Visualisation
@@ -24,6 +16,7 @@ Standard plotting and mapping procedures
    plot_ppi
    plot_ppi_crosshair
    plot_rhi
+   create_cg
    plot_cg_ppi
    plot_cg_rhi
    plot_scan_strategy
@@ -37,32 +30,25 @@ Standard plotting and mapping procedures
 
 # standard libraries
 import os.path as path
-import math
 
 # site packages
 import numpy as np
-import pylab as pl
-import matplotlib
 import matplotlib as mpl
 import matplotlib.pyplot as pl
 from matplotlib import patches
 from matplotlib.projections import PolarAxes, register_projection
 from matplotlib.transforms import Affine2D, Bbox, IdentityTransform
-from mpl_toolkits.axisartist import SubplotHost, ParasiteAxesAuxTrans, GridHelperCurveLinear
+from mpl_toolkits.axisartist import (SubplotHost, ParasiteAxesAuxTrans,
+                                     GridHelperCurveLinear)
 from mpl_toolkits.axisartist.grid_finder import FixedLocator
-from mpl_toolkits.axes_grid1 import make_axes_locatable
-from mpl_toolkits.axes_grid1 import axes_size as Size
-import mpl_toolkits.axisartist.angle_helper as angle_helper
+import mpl_toolkits.axisartist.angle_helper as ah
 from matplotlib.ticker import NullFormatter, FuncFormatter
 import matplotlib.dates as mdates
 from matplotlib.collections import LineCollection, PolyCollection
-import matplotlib.font_manager as fm
 
 # wradlib modules
 from . import georef as georef
 from . import util as util
-from .util import apichange_kwarg
-from .util import deprecated
 
 
 class NorthPolarAxes(PolarAxes):
@@ -141,15 +127,16 @@ def plot_ppi(data, r=None, az=None, autoext=True,
     as making it easier to plot additional data (like gauge locations) without
     having to convert them to the radar's polar coordinate system.
 
-    `**kwargs` may be used to try to influence the matplotlib.pcolormesh and
-    wradlib.georef.polar2lonlatalt_n routines under the hood.
+    `**kwargs` may be used to try to influence the
+    :func:`matplotlib.pyplot.pcolormesh` and
+    :meth:`wradlib.georef.polar2lonlatalt_n` routines under the hood.
 
     There is one major caveat concerning the values of `r` and `az`.
-    Due to the way matplotlib.pcolormesh works, `r` should give the location
-    of the start of each range bin, while `az` should give the angle also at
-    the begin (i.e. 'leftmost') of the beam. This might be in contrast to
-    other conventions, which might define ranges and angles at the center of
-    bin and beam.
+    Due to the way :func:`matplotlib.pyplot.pcolormesh` works, `r` should give
+    the location of the start of each range bin, while `az` should give the
+    angle also at the begin (i.e. 'leftmost') of the beam.
+    This might be in contrast to other conventions, which might define ranges
+    and angles at the center of bin and beam.
     This affects especially the default values set for `r` and `az`, but ìt
     should be possible to accommodate all other conventions by setting `r` and
     `az` properly.
@@ -160,14 +147,15 @@ def plot_ppi(data, r=None, az=None, autoext=True,
         The data to be plotted. It is assumed that the first dimension is over
         the azimuth angles, while the second dimension is over the range bins
     r : np.array
-        The ranges. Units may be chosen arbitrarily, unless proj is set. In that
-        case the units must be meters. If None, a default is
+        The ranges. Units may be chosen arbitrarily, unless proj is set. In
+        that case the units must be meters. If None, a default is
         calculated from the dimensions of `data`.
     az : np.array
         The azimuth angles in degrees. If None, a default is
         calculated from the dimensions of `data`.
     autoext : True | False
-        This routine uses matplotlib.pyplot.pcolormesh to draw the bins.
+        This routine uses :func:`matplotlib.pyplot.pcolormesh` to draw the
+        bins.
         As this function needs one set of coordinates more than would usually
         be provided by `r` and `az`, setting ´autoext´ to True automatically
         extends r and az so that all of `data` will be plotted.
@@ -192,7 +180,7 @@ def plot_ppi(data, r=None, az=None, autoext=True,
     See also
     --------
     wradlib.georef.reproject - for information on projection strings
-    wradlib.georef.create_osr - routine to generate pre-defined projection strings
+    wradlib.georef.create_osr - generate pre-defined projection strings
 
     Returns
     -------
@@ -202,6 +190,10 @@ def plot_ppi(data, r=None, az=None, autoext=True,
         The result of the pcolormesh operation. Necessary, if you want to
         add a colorbar to the plot.
 
+    Examples
+    --------
+    See :ref:`notebooks/visualisation/wradlib_plot_ppi_example.ipynb`.
+
     """
     # kwargs handling
     kw_polar2lonlatalt_n = {}
@@ -249,7 +241,8 @@ def plot_ppi(data, r=None, az=None, autoext=True,
             # therefore we need to get from km to m
             xx *= 1000
         # latitude longitudes from the polar data still stored in xx and yy
-        lon, lat, alt = georef.polar2lonlatalt_n(xx, yy, elev, site, **kw_polar2lonlatalt_n)
+        lon, lat, alt = georef.polar2lonlatalt_n(xx, yy, elev, site,
+                                                 **kw_polar2lonlatalt_n)
         # projected to the final coordinate system
         xx, yy = georef.reproject(lon, lat, projection_target=proj)
 
@@ -289,8 +282,8 @@ def plot_ppi_crosshair(site, ranges, angles=None,
         the underlying PPI plot. Otherwise the ranges must be given in meters.
     angles : list
         List of angles (in degrees) for which straight lines should be drawn.
-        These lines will be drawn starting from the center and until the largest
-        range.
+        These lines will be drawn starting from the center and until the
+        largest range.
     proj : osr spatial reference object
         GDAL OSR Spatial Reference Object describing projection
         The function will calculate lines and circles according to
@@ -310,13 +303,13 @@ def plot_ppi_crosshair(site, ranges, angles=None,
     Keyword Arguments
     -----------------
     line :  dict
-        dictionary, which will be passed to the crosshair line objects using the standard keyword inheritance
-        mechanism. If not given defaults will be used.
+        dictionary, which will be passed to the crosshair line objects using
+        the standard keyword inheritance mechanism. If not given defaults will
+        be used.
     circle : dict
-        dictionary, which will be passed to the range circle line objects using the standard keyword inheritance
-        mechanism. If not given defaults will be used.
-
-    See the file plot_ppi_example.py in the examples folder for examples on how this works.
+        dictionary, which will be passed to the range circle line objects using
+        the standard keyword inheritance mechanism. If not given defaults will
+        be used.
 
     See also
     --------
@@ -327,6 +320,10 @@ def plot_ppi_crosshair(site, ranges, angles=None,
     ax : matplotlib Axes object
         The axes object into which the PPI was plotted
 
+    Examples
+    --------
+    See :ref:`notebooks/visualisation/wradlib_plot_ppi_example.ipynb`.
+
     """
     # if we didn't get an axes object, find the current one
     if ax is None:
@@ -353,16 +350,20 @@ def plot_ppi_crosshair(site, ranges, angles=None,
         # these lines might not be straigt so we approximate them with 10
         # segments. Produce polar coordinates
         rr, az = np.meshgrid(np.linspace(0, ranges[-1], 10), angles)
-        # and reproject using polar2lonlatalt to convert from polar to geographic
-        nsewx, nsewy = georef.reproject(*georef.polar2lonlatalt_n(rr, az, elev, site)[:2],
+        # and reproject using polar2lonlatalt to convert from polar
+        # to geographic
+        nsewx, nsewy = georef.reproject(*georef.polar2lonlatalt_n(rr,
+                                                                  az,
+                                                                  elev,
+                                                                  site)[:2],
                                         projection_target=proj)
     else:
         # no projection
         psite = site
         rr, az = np.meshgrid(np.linspace(0, ranges[-1], 2), angles)
         # use simple trigonometry to calculate coordinates
-        nsewx, nsewy = (psite[0] + rr * np.cos(np.radians(az)),
-                        psite[1] + rr * np.sin(np.radians(az)))
+        nsewx, nsewy = (psite[0] + rr * np.cos(np.radians(90 - az)),
+                        psite[1] + rr * np.sin(np.radians(90 - az)))
 
     # mark the site, just in case nothing else would be drawn
     ax.plot(*psite, marker='+', **linekw)
@@ -388,7 +389,8 @@ def plot_ppi_crosshair(site, ranges, angles=None,
             # in the unprojected case, we may use 'true' circles.
             ax.add_patch(patches.Circle(psite, r, **circkw))
 
-    # there should be not much wrong, setting the axes aspect to equal by default
+    # there should be not much wrong, setting the axes aspect to equal
+    # by default
     ax.set_aspect('equal')
 
     # return the axes object for later use
@@ -404,8 +406,8 @@ def plot_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
     as making it easier to plot additional data (like gauge locations) without
     having to convert them to the radar's polar coordinate system.
 
-    `**kwargs` may be used to try to influence the matplotlib.pcolormesh routine
-     under the hood.
+    `**kwargs` may be used to try to influence the
+    :func:`matplotlib.pyplot.pcolormesh` routine under the hood.
 
     Parameters
     ----------
@@ -422,10 +424,11 @@ def plot_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
         In RHI's it happens that the elevation angles are spaced wider than
         the beam width. If this beam width (in degrees) is given in `th_res`,
         plot_rhi will plot the beams accordingly. Otherwise the behavior of
-        matplotlib.pyplot.pcolormesh assumes all beams to be adjacent to each
-        other, which might lead to unexpected results.
+        :func:`matplotlib.pyplot.pcolormesh` assumes all beams to be adjacent
+        to each other, which might lead to unexpected results.
     autoext : True | False
-        This routine uses matplotlib.pyplot.pcolormesh to draw the bins.
+        This routine uses :func:`matplotlib.pyplot.pcolormesh` to draw
+        the bins.
         As this function needs one set of coordinates more than would usually
         provided by `r` and `az`, setting ´autoext´ to True automatically
         extends r and az so that all of `data` will be plotted.
@@ -434,9 +437,10 @@ def plot_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
         beam propagation will be taken into account. If False, simple
         trigonometry will be used to calculate beam propagation.
         Functionality for this will be provided by functions
-        wradlib.georef.arc_distance_n and wradlib.georef.beam_height_n, which
-        assume distances to be given in meters. Therefore, if `refrac` is True,
-        `r` must be given in meters.
+        :meth:`wradlib.georef.arc_distance_n` and
+        :meth:`wradlib.georef.beam_height_n`, which assume distances to be
+        given in meters. Therefore, if `refrac` is True, `r` must be given
+        in meters.
     ax : matplotlib Axes object
         If given, the RHI will be plotted into this axes object. If None a
         new axes object will be created.
@@ -525,13 +529,15 @@ def create_cg(st, fig=None, subplot=111):
     """ Helper function to create curvelinear grid
 
     The function makes use of the Matplotlib AXISARTIST namespace
-    http://matplotlib.org/mpl_toolkits/axes_grid/users/axisartist.html
+    `mpl_toolkits.axisartist \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/users/axisartist.html>`_.
 
     Here are some limitations to normal Matplotlib Axes. While using the
-    Matplotlib AxesGrid Toolkit
-    http://matplotlib.org/mpl_toolkits/axes_grid/index.html
+    Matplotlib `AxesGrid Toolkit \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/index.html>`_
     most of the limitations can be overcome.
-    See http://matplotlib.org/mpl_toolkits/axes_grid/users/index.html.
+    See `Matplotlib AxesGrid Toolkit User’s Guide \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/users/index.html>`_.
 
     Parameters
     ----------
@@ -560,16 +566,16 @@ def create_cg(st, fig=None, subplot=111):
         tr = Affine2D().scale(np.pi / 180, 1) + PolarAxes.PolarTransform()
 
         # build up curvelinear grid
-        extreme_finder = angle_helper.ExtremeFinderCycle(20, 20,
-                                                         lon_cycle=100,
-                                                         lat_cycle=None,
-                                                         lon_minmax=(0, np.inf),
-                                                         lat_minmax=(0, np.inf),
-                                                         )
+        extreme_finder = ah.ExtremeFinderCycle(20, 20,
+                                               lon_cycle=100,
+                                               lat_cycle=None,
+                                               lon_minmax=(0, np.inf),
+                                               lat_minmax=(0, np.inf),
+                                               )
 
         # locator and formatter for angular annotation
-        grid_locator1 = angle_helper.LocatorDMS(10.)
-        tick_formatter1 = angle_helper.FormatterDMS()
+        grid_locator1 = ah.LocatorDMS(10.)
+        tick_formatter1 = ah.FormatterDMS()
 
         # grid_helper for curvelinear grid
         grid_helper = GridHelperCurveLinear(tr,
@@ -591,17 +597,17 @@ def create_cg(st, fig=None, subplot=111):
               NorthPolarAxes.NorthPolarTransform())
 
         # build up curvelinear grid
-        extreme_finder = angle_helper.ExtremeFinderCycle(20, 20,
-                                                         lon_cycle=360,
-                                                         lat_cycle=None,
-                                                         lon_minmax=(350, 0),
-                                                         lat_minmax=(0, np.inf),
-                                                         )
+        extreme_finder = ah.ExtremeFinderCycle(20, 20,
+                                               lon_cycle=360,
+                                               lat_cycle=None,
+                                               lon_minmax=(350, 0),
+                                               lat_minmax=(0, np.inf),
+                                               )
 
         # locator and formatter for angle annotation
         grid_locator1 = FixedLocator([i for i in np.arange(0, 359, 10)])
-        grid_locator1 = angle_helper.LocatorDMS(35)
-        tick_formatter1 = angle_helper.FormatterDMS()
+        grid_locator1 = ah.LocatorDMS(35)
+        tick_formatter1 = ah.FormatterDMS()
 
         # grid_helper for curvelinear grid
         grid_helper = GridHelperCurveLinear(tr,
@@ -677,13 +683,15 @@ def plot_cg_ppi(data, r=None, az=None, rf=1.0, autoext=True,
     coordinates depending which axes object is used.
 
     The function uses create_cg which uses the Matplotlib AXISARTIST namespace
-    http://matplotlib.org/mpl_toolkits/axes_grid/users/axisartist.html
+    `mpl_toolkits.axisartist \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/users/axisartist.html>`_.
 
     Here are some limitations to normal Matplotlib Axes. While using the
-    Matplotlib AxesGrid Toolkit
-    http://matplotlib.org/mpl_toolkits/axes_grid/index.html
+    Matplotlib `AxesGrid Toolkit \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/index.html>`_
     most of the limitations can be overcome.
-    See http://matplotlib.org/mpl_toolkits/axes_grid/users/index.html.
+    See `Matplotlib AxesGrid Toolkit User’s Guide \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/users/index.html>`_.
 
     `**kwargs` may be used to try to influence the matplotlib.pcolormesh
     routine under the hood.
@@ -703,7 +711,8 @@ def plot_cg_ppi(data, r=None, az=None, rf=1.0, autoext=True,
         The azimuth angles in degrees. If None, a default is
         calculated from the dimensions of `data`.
     autoext : True | False
-        This routine uses matplotlib.pyplot.pcolormesh to draw the bins.
+        This routine uses :func:`matplotlib.pyplot.pcolormesh` to draw
+        the bins.
         As this function needs one set of coordinates more than would usually
         be provided by `r` and `az`, setting ´autoext´ to True automatically
         extends r and az so that all of `data` will be plotted.
@@ -711,8 +720,8 @@ def plot_cg_ppi(data, r=None, az=None, rf=1.0, autoext=True,
         If True, the effect of refractivity of the earth's atmosphere on the
         beam propagation will be taken into account. If False, simple
         trigonometry will be used to calculate beam propagation.
-        Functionality for this will be provided by functions
-        wradlib.georef.arc_distance_n. Therefore, if `refrac` is True,
+        Functionality for this will be provided by function
+        :meth:`wradlib.georef.arc_distance_n`. Therefore, if `refrac` is True,
         `r` must be given in meters.
     elev : float or array of same shape as az
         Elevation angle of the scan or individual azimuths.
@@ -742,6 +751,10 @@ def plot_cg_ppi(data, r=None, az=None, rf=1.0, autoext=True,
     pm : matplotlib QuadMesh object
         The result of the pcolormesh operation. Necessary, if you want to
         add a colorbar to the plot.
+
+    Examples
+    --------
+    See :ref:`notebooks/visualisation/wradlib_plot_curvelinear_grids.ipynb`.
     """
 
     # this may seem odd at first, but d1 and d2 are also used in plot_rhi
@@ -818,16 +831,18 @@ def plot_cg_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
     Plotting in the radar's polar coordinate system is possible as well.
 
     The function uses create_cg wich uses the Matplotlib AXISARTIST namespace
-    http://matplotlib.org/mpl_toolkits/axes_grid/users/axisartist.html
+    `mpl_toolkits.axisartist \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/users/axisartist.html>`_.
 
     Here are some limitations to normal Matplotlib Axes. While using the
-    Matplotlib AxesGrid Toolkit
-    http://matplotlib.org/mpl_toolkits/axes_grid/index.html
+    Matplotlib `AxesGrid Toolkit \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/index.html>`_
     most of the limitations can be overcome.
-    See http://matplotlib.org/mpl_toolkits/axes_grid/users/index.html.
+    See `Matplotlib AxesGrid Toolkit User’s Guide \
+    <http://matplotlib.org/mpl_toolkits/axes_grid/users/index.html>`_.
 
-    `**kwargs` may be used to try to influence the matplotlib.pcolormesh
-    routine under the hood.
+    `**kwargs` may be used to try to influence :func:`matplotlib.pcolormesh`
+    under the hood.
 
     Parameters
     ----------
@@ -848,8 +863,8 @@ def plot_cg_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
         In RHI's it happens that the elevation angles are spaced wider than
         the beam width. If this beam width (in degrees) is given in `th_res`,
         plot_rhi will plot the beams accordingly. Otherwise the behavior of
-        matplotlib.pyplot.pcolormesh assumes all beams to be adjacent to each
-        other, which might lead to unexpected results.
+        :func:`matplotlib.pyplot.pcolormesh` assumes all beams to be adjacent
+        to each other, which might lead to unexpected results.
     autoext : True | False
         This routine uses matplotlib.pyplot.pcolormesh to draw the bins.
         As this function needs one set of coordinates more than would usually
@@ -859,11 +874,13 @@ def plot_cg_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
         If True, the effect of refractivity of the earth's atmosphere on the
         beam propagation will be taken into account.
         Functionality for this will be provided by functions
-        wradlib.georef.arc_distance_n and wradlib.georef.beam_height_n, which
+        :meth:`wradlib.georef.arc_distance_n` and
+        :meth:`wradlib.georef.beam_height_n`, which
         assume distances to be given in meters. Therefore, if `refrac` is True,
         `r` must be given in meters. Cartesian Axis caax ist used for plotting.
-        If False, PolarAxes.PolarTransform will be used to calculate
-        beam propagation.
+        If False,
+        :class:`~matplotlib.projections.polar.PolarAxes.PolarTransform`
+        will be used to calculate beam propagation.
     fig : matplotlib Figure object
         If given, the RHI will be plotted into this figure object. Axes are
         created as needed. If None a new figure object will be created or
@@ -888,6 +905,10 @@ def plot_cg_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
     pm : matplotlib QuadMesh object
         The result of the pcolormesh operation. Necessary, if you want to
         add a colorbar to the plot.
+
+    Examples
+    --------
+    See :ref:`notebooks/visualisation/wradlib_plot_curvelinear_grids.ipynb`.
     """
 
     # autogenerate axis dimensions
@@ -983,7 +1004,8 @@ def plot_cg_rhi(data, r=None, th=None, th_res=None, autoext=True, refrac=True,
     return cgax, caax, paax, pm
 
 
-def plot_scan_strategy(ranges, elevs, site, vert_res=500., maxalt=10000., ax=None):
+def plot_scan_strategy(ranges, elevs, site, vert_res=500.,
+                       maxalt=10000., ax=None):
     """Plot the vertical scanning strategy
 
     Parameters
@@ -998,7 +1020,8 @@ def plot_scan_strategy(ranges, elevs, site, vert_res=500., maxalt=10000., ax=Non
     polc = util.meshgridN(ranges, az, elevs)
 
     # get mean height over radar
-    lon, lat, alt = georef.polar2lonlatalt_n(polc[0].ravel(), polc[1].ravel(), polc[2].ravel(), site)
+    lon, lat, alt = georef.polar2lonlatalt_n(polc[0].ravel(), polc[1].ravel(),
+                                             polc[2].ravel(), site)
     alt = alt.reshape(len(ranges), len(elevs))
     r = polc[0].reshape(len(ranges), len(elevs))
 
@@ -1033,8 +1056,10 @@ def plot_scan_strategy(ranges, elevs, site, vert_res=500., maxalt=10000., ax=Non
     pl.show()
 
 
-def plot_plan_and_vert(x, y, z, dataxy, datazx, datazy, unit="", title="", saveto="", **kwargs):
-    """Plot 2-D plan view of <dataxy> together with vertical sections <dataxz> and <datazy>
+def plot_plan_and_vert(x, y, z, dataxy, datazx, datazy, unit="",
+                       title="", saveto="", **kwargs):
+    """Plot 2-D plan view of <dataxy> together with
+    vertical sections <dataxz> and <datazy>
 
     Parameters
     ----------
@@ -1050,11 +1075,12 @@ def plot_plan_and_vert(x, y, z, dataxy, datazx, datazy, unit="", title="", savet
 
     Keyword Arguments
     -----------------
-    **kwargs : other kwargs which can be passed to pylab.contourf
+    **kwargs : other kwargs which can be passed to \
+               :func:`matplotlib.pyplot.contourf`
 
     """
 
-    fig = pl.figure(figsize=(10, 10))
+    pl.figure(figsize=(10, 10))
 
     # define axes
     left, bottom, width, height = 0.1, 0.1, 0.6, 0.2
@@ -1108,9 +1134,10 @@ def plot_plan_and_vert(x, y, z, dataxy, datazx, datazy, unit="", title="", savet
     ax_y.xaxis.set_major_formatter(zformatter)
 
     if not title == "":
-        # add a title - here, we have to create a new axes object which will be invisible
-        # then the invisible axes will get a title
-        tax = pl.axes((left, bottom + width + height + 0.01, width + height, 0.01), frameon=False, axisbg="none")
+        # add a title - here, we have to create a new axes object which will
+        # be invisible then the invisible axes will get a title
+        tax = pl.axes((left, bottom + width + height + 0.01,
+                       width + height, 0.01), frameon=False, axisbg="none")
         tax.get_xaxis().set_visible(False)
         tax.get_yaxis().set_visible(False)
         pl.title(title)
@@ -1127,15 +1154,23 @@ def plot_plan_and_vert(x, y, z, dataxy, datazx, datazy, unit="", title="", savet
             pl.close()
 
 
-def plot_max_plan_and_vert(x, y, z, data, unit="", title="", saveto="", **kwargs):
-    """Plot according to <plot_plan_and_vert> with the maximum values along the three axes of <data>
+def plot_max_plan_and_vert(x, y, z, data, unit="", title="",
+                           saveto="", **kwargs):
+    """Plot according to <plot_plan_and_vert> with the maximum values
+    along the three axes of <data>
+
+    Examples
+    --------
+    See :ref:`notebooks/workflow/recipe2.ipynb`.
     """
-    plot_plan_and_vert(x, y, z, np.max(data, axis=-3), np.max(data, axis=-2), np.max(data, axis=-1),
+    plot_plan_and_vert(x, y, z, np.max(data, axis=-3), np.max(data, axis=-2),
+                       np.max(data, axis=-1),
                        unit, title, saveto, **kwargs)
 
 
-def plot_tseries(dtimes, data, ax=None, labels=None, datefmt='%b %d, %H:%M', colors=None, ylabel="",
-                 title="", fontsize="medium", saveto="", **kwargs):
+def plot_tseries(dtimes, data, ax=None, labels=None, datefmt='%b %d, %H:%M',
+                 colors=None, ylabel="", title="", fontsize="medium",
+                 saveto="", **kwargs):
     """Plot time series data (e.g. gage recordings)
 
     Parameters
@@ -1144,7 +1179,7 @@ def plot_tseries(dtimes, data, ax=None, labels=None, datefmt='%b %d, %H:%M', col
     data : 2D array of shape ( num time steps, num data series )
     labels : list of strings (names of data series)
     title : string
-    kwargs : keyword arguments related to pylab.plot
+    kwargs : keyword arguments related to :func:`matplotlib.pyplot.plot`
 
     """
     if ax is None:
@@ -1156,7 +1191,8 @@ def plot_tseries(dtimes, data, ax=None, labels=None, datefmt='%b %d, %H:%M', col
     # if labels==None:
     #    labels = ["series%d"%i for i in range(1, data.shape[1]+1)]
     # for i, label in enumerate(labels):
-    #    ax.plot_date(mpl.dates.date2num(dtimes),data[:,i],label=label, color=colors[i], **kwargs)
+    #    ax.plot_date(mpl.dates.date2num(dtimes),data[:,i],label=label,
+    #                 color=colors[i], **kwargs)
     ax.plot_date(mpl.dates.date2num(dtimes), data, **kwargs)
     ax.xaxis.set_major_formatter(mdates.DateFormatter(datefmt))
     pl.setp(ax.get_xticklabels(), visible=True)
@@ -1201,8 +1237,12 @@ def add_lines(ax, lines, **kwargs):
     Parameters
     ----------
     ax : :class:`matplotlib:matplotlib.axes.Axes`
-    lines : nested numpy Nx2 array(s)
+    lines : nested :class:`numpy:numpy.ndarray` Nx2 array(s)
     kwargs : :class:`matplotlib:matplotlib.collections.LineCollection`
+
+    Examples
+    --------
+    See :ref:`notebooks/visualisation/wradlib_overlay.ipynb`.
     """
     try:
         ax.add_collection(LineCollection([lines], **kwargs))
@@ -1226,8 +1266,12 @@ def add_patches(ax, patch_array, **kwargs):
     Parameters
     ----------
     ax : :class:`matplotlib:matplotlib.axes.Axes`
-    patch_array : nested numpy Nx2 array(s)
+    patch_array : nested :class:`numpy:numpy.ndarray` Nx2 array(s)
     kwargs : :class:`matplotlib:matplotlib.collections.PolyCollection`
+
+    Examples
+    --------
+    See :ref:`notebooks/visualisation/wradlib_overlay.ipynb`.
     """
 
     try:
