@@ -1,14 +1,7 @@
 #!/usr/bin/env python
-# -------------------------------------------------------------------------------
-# Name:        zonalstats
-# Purpose:
-#
-# Author:      Maik Heistermann, Kai Muehlbauer
-#
-# Created:     12.11.2015
-# Copyright:   (c) Maik Heistermann, Kai Muehlbauer 2015
-# Licence:     The MIT License
-# -------------------------------------------------------------------------------
+# Copyright (c) 2016, wradlib developers.
+# Distributed under the MIT License. See LICENSE.txt for more info.
+
 """
 Zonal Statistics
 ^^^^^^^^^^^^^^^^
@@ -16,26 +9,29 @@ Zonal Statistics
 .. versionadded:: 0.7.0
 
 This module supports you in computing statistics over spatial zones. A typical
-application would be to compute mean areal precipitation for a catchment by using
-precipitation estimates from a radar grid in polar coordinates or from precipitation
-estimates in a Cartesian grid.
+application would be to compute mean areal precipitation for a catchment by
+using precipitation estimates from a radar grid in polar coordinates or from
+precipitation estimates in a Cartesian grid.
 
 The general usage is similar to the ipol and adjustment modules:
 
-You have to create an instance of a class (derived from ZonalDataBase) by using the
-spatial information of your source and target objects (e.g. radar bins and
-catchment polygons). The Zonal Data within this object can be saved as an ESRI Shapefile.
+You have to create an instance of a class (derived from ZonalDataBase) by using
+the spatial information of your source and target objects (e.g. radar bins and
+catchment polygons). The Zonal Data within this object can be saved as an
+ESRI Shapefile.
 
-This object is then called with another class to compute zonal statistics for your target
-objects by calling the class instance with an array of values (one for each source object).
+This object is then called with another class to compute zonal statistics for
+your target objects by calling the class instance with an array of values
+(one for each source object).
 
-Typically, creating the instance of the ZonalData class will be computationally expensive,
-but only has to be done once (as long as the geometries do not change).
+Typically, creating the instance of the ZonalData class will be computationally
+expensive, but only has to be done once (as long as the geometries do
+not change).
 
 Calling the objects with actual data, however, will be very fast.
 
-.. note:: Right now we only support a limited set of 2-dimensional zonal statistics.
-         In the future, we plan to extend this to three dimensions.
+.. note:: Right now we only support a limited set of 2-dimensional zonal
+         statistics. In the future, we plan to extend this to three dimensions.
 
 .. currentmodule:: wradlib.zonalstats
 
@@ -56,7 +52,6 @@ Calling the objects with actual data, however, will be very fast.
 import os
 import numpy as np
 from scipy.spatial import cKDTree
-import datetime as dt
 from matplotlib.path import Path
 import matplotlib.patches as patches
 from osgeo import gdal, ogr
@@ -86,6 +81,10 @@ class DataSource(object):
     Writing shapefiles with the wrong locale settings can have impact on the
     type of the decimal. If problem arise use LC_NUMERIC=C in your environment.
 
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#\
+DataSource`.
     """
 
     def __init__(self, data=None, srs=None, **kwargs):
@@ -183,13 +182,15 @@ class DataSource(object):
 
             - array cast of source elements
             - create ogr_src datasource/layer holding src points/polygons
-            - transforming source grid points/polygons to ogr.geometries on ogr.layer
+            - transforming source grid points/polygons to ogr.geometries
+              on ogr.layer
         """
         ogr_src = ogr_create_datasource('Memory', 'out')
 
         try:
             # is it ESRI Shapefile?
-            ds_in, tmp_lyr = io.open_shape(src, driver=ogr.GetDriverByName('ESRI Shapefile'))
+            ds_in, tmp_lyr = io.open_shape(src, driver=ogr.
+                                           GetDriverByName('ESRI Shapefile'))
             ogr_src_lyr = ogr_src.CopyLayer(tmp_lyr, self._name)
             if self._srs is None:
                 self._srs = ogr_src_lyr.GetSpatialRef()
@@ -206,7 +207,8 @@ class DataSource(object):
             else:
                 geom_type = ogr.wkbPolygon
             fields = [('index', ogr.OFTInteger)]
-            ogr_create_layer(ogr_src, self._name, srs=self._srs, geom_type=geom_type, fields=fields)
+            ogr_create_layer(ogr_src, self._name, srs=self._srs,
+                             geom_type=geom_type, fields=fields)
             ogr_add_feature(ogr_src, src, name=self._name)
 
         return ogr_src
@@ -230,7 +232,8 @@ class DataSource(object):
         # flush everything
         del ds_out
 
-    def dump_raster(self, filename, driver='GTiff', attr=None, pixel_size=1., remove=True):
+    def dump_raster(self, filename, driver='GTiff', attr=None,
+                    pixel_size=1., remove=True):
         """ Output layer to GDAL Rasterfile
 
         Parameters
@@ -256,7 +259,8 @@ class DataSource(object):
         rows = int((y_max - y_min) / pixel_size)
 
         # Todo: at the moment, always writing floats
-        ds_out = gdal_create_dataset(driver, filename, cols, rows, gdal.GDT_Float32, remove=remove)
+        ds_out = gdal_create_dataset(driver, filename, cols, rows,
+                                     gdal.GDT_Float32, remove=remove)
         ds_out.SetGeoTransform((x_min, pixel_size, 0, y_max, 0, -pixel_size))
         proj = layer.GetSpatialRef()
         if proj is None:
@@ -268,7 +272,8 @@ class DataSource(object):
         print("Rasterizing Layer")
         if attr is not None:
             gdal.RasterizeLayer(ds_out, [1], layer, burn_values=[0],
-                                options=["ATTRIBUTE={0}".format(attr), "ALL_TOUCHED=TRUE"],
+                                options=["ATTRIBUTE={0}".format(attr),
+                                         "ALL_TOUCHED=TRUE"],
                                 callback=gdal.TermProgress)
         else:
             gdal.RasterizeLayer(ds_out, [1], layer, burn_values=[1],
@@ -284,7 +289,7 @@ class DataSource(object):
         ----------
         name : string
             Attribute Name
-        values : ndarray
+        values : :class:`numpy:numpy.ndarray`
             Values to fill in attributes
         """
 
@@ -345,7 +350,8 @@ class DataSource(object):
 class ZonalDataBase(object):
     """
     The base class for managing 2-dimensional zonal data for target polygons
-    from source points or polygons. Provides the basic design for all other classes.
+    from source points or polygons. Provides the basic design for all other
+    classes.
 
     If no source points or polygons can be associated to a target polygon (e.g.
     no intersection), the created destination layer will be empty.
@@ -378,12 +384,17 @@ class ZonalDataBase(object):
     -----------------
     buf : float
         (same unit as coordinates)
-        Points/Polygons  will be considered inside the target if they are contained in the buffer.
+        Points/Polygons  will be considered inside the target if they are
+        contained in the buffer.
 
     srs : OGR.SpatialReference
         will be used for DataSource object.
         src and trg data have to be in the same srs-format
 
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
+
     """
     def __init__(self, src, trg=None, buf=0., srs=None, **kwargs):
         self._buffer = buf
@@ -408,11 +419,12 @@ class ZonalDataBase(object):
 
         Returns
         -------
-        array : ndarray
+        array : :class:`numpy:numpy.ndarray`
             of Nx2 point coordinate arrays
         """
         return np.array([self._get_intersection(idx=idx)
-                         for idx in range(self.trg.ds.GetLayerByName('trg').GetFeatureCount())])
+                         for idx in range(self.trg.ds.GetLayerByName('trg').
+                                          GetFeatureCount())])
 
     def get_isec(self, idx):
         """ Returns intersections
@@ -424,7 +436,7 @@ class ZonalDataBase(object):
 
         Returns
         -------
-        array : ndarray
+        array : :class:`numpy:numpy.ndarray`
             of Nx2 point coordinate arrays
         """
         return self._get_intersection(idx=idx)
@@ -439,10 +451,11 @@ class ZonalDataBase(object):
 
         Returns
         -------
-        array : np.ndarray
+        array : :class:`numpy:numpy.ndarray`
             indices
         """
-        return np.array(self.dst.get_attributes(['src_index'], filt=('trg_index', idx))[0])
+        return np.array(self.dst.get_attributes(['src_index'],
+                                                filt=('trg_index', idx))[0])
 
     def _create_dst_datasource(self, **kwargs):
         """ Create destination target OGR.DataSource
@@ -473,7 +486,8 @@ class ZonalDataBase(object):
 
         for i in range(tmp_trg_lyr.GetFeatureCount()):
             feat = tmp_trg_lyr.GetFeature(i)
-            feat.SetGeometryDirectly(feat.GetGeometryRef().Buffer(self._buffer))
+            feat.SetGeometryDirectly(feat.GetGeometryRef().
+                                     Buffer(self._buffer))
             tmp_trg_lyr.SetFeature(feat)
 
         # get target layer, iterate over polygons and calculate intersections
@@ -484,21 +498,23 @@ class ZonalDataBase(object):
 
         print("Calculate Intersection source/target-layers")
         try:
-            tmp_trg_lyr.Intersection(src_lyr, self.tmp_lyr, options=['SKIP_FAILURES=YES',
-                                                                     'INPUT_PREFIX=trg_',
-                                                                     'METHOD_PREFIX=src_',
-                                                                     'PROMOTE_TO_MULTI=YES',
-                                                                     'PRETEST_CONTAINMENT=YES'],
+            tmp_trg_lyr.Intersection(src_lyr, self.tmp_lyr,
+                                     options=['SKIP_FAILURES=YES',
+                                              'INPUT_PREFIX=trg_',
+                                              'METHOD_PREFIX=src_',
+                                              'PROMOTE_TO_MULTI=YES',
+                                              'PRETEST_CONTAINMENT=YES'],
                                      callback=gdal.TermProgress)
         except RuntimeError:
-            # Catch RuntimeError that was reported on gdal 1.11.1 on Windows systems
-            tmp_trg_lyr.Intersection(src_lyr, self.tmp_lyr, options=['SKIP_FAILURES=YES',
-                                                                     'INPUT_PREFIX=trg_',
-                                                                     'METHOD_PREFIX=src_',
-                                                                     'PROMOTE_TO_MULTI=YES',
-                                                                     'PRETEST_CONTAINMENT=YES'])
-        
-        
+            # Catch RuntimeError that was reported on gdal 1.11.1
+            # on Windows systems
+            tmp_trg_lyr.Intersection(src_lyr, self.tmp_lyr,
+                                     options=['SKIP_FAILURES=YES',
+                                              'INPUT_PREFIX=trg_',
+                                              'METHOD_PREFIX=src_',
+                                              'PROMOTE_TO_MULTI=YES',
+                                              'PRETEST_CONTAINMENT=YES'])
+
         return ds_mem
 
     def _create_dst_features(self, dst, trg, **kwargs):
@@ -566,8 +582,8 @@ class ZonalDataBase(object):
         raise NotImplementedError
 
     def _get_intersection(self, trg=None, idx=None, buf=0.):
-        """Just a toy function if you want to inspect the intersection points/polygons
-        of an arbitrary target or an target by index.
+        """Just a toy function if you want to inspect the intersection
+        points/polygons of an arbitrary target or an target by index.
         """
         # TODO: kwargs necessary?
 
@@ -579,7 +595,8 @@ class ZonalDataBase(object):
                     feat = lyr.GetFeature(idx)
                     trg = feat.GetGeometryRef()
                 except:
-                    raise TypeError("No target polygon found at index {0}".format(idx))
+                    raise TypeError("No target polygon found at index {0}".
+                                    format(idx))
             else:
                 raise TypeError('No target polygons found in object!')
 
@@ -626,6 +643,9 @@ class ZonalDataPoly(ZonalDataBase):
         will be used for DataSource object.
         src and trg data have to be in the same srs-format
 
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
     """
     def _get_idx_weights(self):
         """ Retrieve index and weight from dst DataSource
@@ -643,8 +663,10 @@ class ZonalDataPoly(ZonalDataBase):
         cnt = trg.GetFeatureCount()
         ret = [[] for _ in range(2)]
         for index in range(cnt):
-            arr = self.dst.get_attributes(['src_index'], filt=('trg_index', index))
-            w = self.dst.get_geom_properties(['Area'], filt=('trg_index', index))
+            arr = self.dst.get_attributes(['src_index'],
+                                          filt=('trg_index', index))
+            w = self.dst.get_geom_properties(['Area'],
+                                             filt=('trg_index', index))
             arr.append(w[0])
             for i, l in enumerate(arr):
                 ret[i].append(np.array(l))
@@ -680,7 +702,8 @@ class ZonalDataPoly(ZonalDataBase):
             if not trg.Contains(geom):
                 geom = trg.Intersection(geom)
 
-            # checking GeometryCollection, convert to only Polygons, Multipolygons
+            # checking GeometryCollection, convert to only Polygons,
+            #  Multipolygons
             if geom.GetGeometryType() in [7]:
                 geocol = ogr_geocol_to_numpy(geom)
                 geom = numpy_to_ogr(geocol, 'MultiPolygon')
@@ -717,6 +740,10 @@ class ZonalDataPoint(ZonalDataBase):
     srs : OGR.SpatialReference
         will be used for DataSource object.
         src and trg data have to be in the same srs-format
+
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
     """
     def _get_idx_weights(self):
         """ Retrieve index and weight from dst DataSource
@@ -732,8 +759,9 @@ class ZonalDataPoint(ZonalDataBase):
         cnt = trg.GetFeatureCount()
         ret = [[] for _ in range(2)]
         for index in range(cnt):
-            arr = self.dst.get_attributes(['src_index'], filt=('trg_index', index))
-            arr.append([1./len(arr[0])] * len(arr[0]))
+            arr = self.dst.get_attributes(['src_index'],
+                                          filt=('trg_index', index))
+            arr.append([1. / len(arr[0])] * len(arr[0]))
             for i, l in enumerate(arr):
                 ret[i].append(np.array(l))
         return tuple(ret)
@@ -768,12 +796,14 @@ class ZonalDataPoint(ZonalDataBase):
              for ogr_src in layer]
         else:
             layer.SetSpatialFilter(None)
-            src_pts = np.array([ogr_src.GetGeometryRef().GetPoint_2D(0) for ogr_src in layer])
+            src_pts = np.array([ogr_src.GetGeometryRef().GetPoint_2D(0)
+                                for ogr_src in layer])
             centroid = get_centroid(trg)
             tree = cKDTree(src_pts)
             distnext, ixnext = tree.query([centroid[0], centroid[1]], k=1)
             feat = layer.GetFeature(ixnext)
-            ogr_add_geometry(dst, feat.GetGeometryRef(), [feat.GetField('index'), trg_index])
+            ogr_add_geometry(dst, feat.GetGeometryRef(),
+                             [feat.GetField('index'), trg_index])
 
 
 class ZonalStatsBase(object):
@@ -784,7 +814,7 @@ class ZonalStatsBase(object):
     The base class for computing 2-dimensional zonal statistics for target
     polygons from source points or polygons as built up with ZonalDataBase
     and derived classes. Provides the basic design for all other classes.
-    
+
     If no source points or polygons can be associated to a target polygon (e.g.
     no intersection), the zonal statistic for that target will be NaN.
 
@@ -795,6 +825,10 @@ class ZonalStatsBase(object):
         containing necessary ZonalData
         ZonalData is available as 'zdata'-property inside class instance.
 
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#\
+ZonalStats`.
     """
     def __init__(self, src=None, ix=None, w=None):
 
@@ -854,7 +888,8 @@ class ZonalStatsBase(object):
                 raise TypeError("parameters ix and w must be of equal length")
             return np.array(ix), np.array(w)
         else:
-            print("ix and w are complementary parameters and must both be given")
+            print("ix and w are complementary parameters and "
+                  "must both be given")
             raise TypeError
 
     def _check_vals(self, vals):
@@ -866,14 +901,16 @@ class ZonalStatsBase(object):
             lyr.ResetReading()
             lyr.SetSpatialFilter(None)
             src_len = lyr.GetFeatureCount()
-            assert len(vals) == src_len, "Argument vals must be of length %d" % src_len
+            assert len(vals) == src_len, \
+                "Argument vals must be of length %d" % src_len
         else:
             imax = 0
             for i in self.ix:
                 mx = np.nanmax(i)
                 if imax < mx:
                     imax = mx
-            assert len(vals) > imax, "Argument vals cannot be subscripted by given index values"
+            assert len(vals) > imax, \
+                "Argument vals cannot be subscripted by given index values"
 
         return vals
 
@@ -883,7 +920,7 @@ class ZonalStatsBase(object):
 
         Parameters
         ----------
-        vals : 1-d ndarray
+        vals : 1-d :class:`numpy:numpy.ndarray`
             of type float with the same length as self.src
             Values at the source element for which to compute zonal statistics
 
@@ -891,30 +928,34 @@ class ZonalStatsBase(object):
         self._check_vals(vals)
         self.isempty = self.check_empty()
         out = np.zeros(len(self.ix)) * np.nan
-        out[~self.isempty] = np.array([np.average(vals[self.ix[i]], weights=self.w[i])
-                                       for i in np.arange(len(self.ix))[~self.isempty]])
+        out[~self.isempty] = np.array(
+            [np.average(vals[self.ix[i]], weights=self.w[i])
+             for i in np.arange(len(self.ix))[~self.isempty]])
 
         if self.zdata is not None:
             self.zdata.trg.set_attribute('mean', out)
 
         return out
-            
+
     def var(self, vals):
         """
-        Evaluate (weighted) zonal variance for values given at the source points.
+        Evaluate (weighted) zonal variance for values given at the source
+        points.
 
         Parameters
         ----------
-        vals : 1-d ndarray
+        vals : 1-d :class:`numpy:numpy.ndarray`
             of type float with the same length as self.src
-            Values at the source element for which to compute zonal statistics
+            Values at the source element for which to compute
+            zonal statistics
 
         """
         self._check_vals(vals)
         mean = self.mean(vals)
         out = np.zeros(len(self.ix)) * np.nan
-        out[~self.isempty] = np.array([np.average((vals[self.ix[i]] - mean[i])**2, weights=self.w[i])
-                                       for i in np.arange(len(self.ix))[~self.isempty]])
+        out[~self.isempty] = np.array(
+            [np.average((vals[self.ix[i]] - mean[i])**2, weights=self.w[i])
+             for i in np.arange(len(self.ix))[~self.isempty]])
 
         if self.zdata is not None:
             self.zdata.trg.set_attribute('var', out)
@@ -938,6 +979,10 @@ class GridCellsToPoly(ZonalStatsBase):
     Keyword arguments
     -----------------
 
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`
+    and :ref:`notebooks/zonalstats/wradlib_zonalstats_example.ipynb`.
     """
     def __init__(self, src=None, **kwargs):
         if src is not None:
@@ -962,6 +1007,10 @@ class GridPointsToPoly(ZonalStatsBase):
     Keyword arguments
     -----------------
 
+    Examples
+    --------
+    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`
+    and :ref:`notebooks/zonalstats/wradlib_zonalstats_example.ipynb`.
     """
     def __init__(self, src, **kwargs):
         if src is not None:
@@ -1147,7 +1196,7 @@ def ogr_add_feature(ds, src, name=None):
     ----------
     ds : OGR.DataSource
         object
-    src : numpy array
+    src : :func:`numpy:numpy.array`
         source data
     name : string
         name of wanted Layer
@@ -1160,7 +1209,8 @@ def ogr_add_feature(ds, src, name=None):
 
     defn = lyr.GetLayerDefn()
     geom_name = ogr.GeometryTypeToName(lyr.GetGeomType())
-    fields = [defn.GetFieldDefn(i).GetName() for i in range(defn.GetFieldCount())]
+    fields = [defn.GetFieldDefn(i).GetName()
+              for i in range(defn.GetFieldCount())]
     feat = ogr.Feature(defn)
 
     for index, src_item in enumerate(src):
@@ -1221,9 +1271,11 @@ def numpy_to_ogr(vert, geom_name):
     """
 
     if geom_name in ['Polygon', 'MultiPolygon']:
-        json_str = "{{'type':{0!r},'coordinates':[{1!r}]}}".format(geom_name, vert.tolist())
+        json_str = "{{'type':{0!r},'coordinates':[{1!r}]}}".\
+            format(geom_name, vert.tolist())
     else:
-        json_str = "{{'type':{0!r},'coordinates':{1!r}}}".format(geom_name, vert.tolist())
+        json_str = "{{'type':{0!r},'coordinates':{1!r}}}".\
+            format(geom_name, vert.tolist())
 
     return ogr.CreateGeometryFromJson(json_str)
 
@@ -1242,7 +1294,7 @@ def ogr_to_numpy(ogrobj):
 
     Returns
     -------
-    out : array_like
+    out : :class:`numpy:numpy.ndarray`
         a nested ndarray of vertices of shape (num vertices, 2)
 
     """
@@ -1267,7 +1319,7 @@ def ogr_geocol_to_numpy(ogrobj):
 
     Returns
     -------
-    out : ndarray
+    out : :class:`numpy:numpy.ndarray`
         a nested ndarray of vertices of shape (num vertices, 2)
 
     """
@@ -1286,12 +1338,12 @@ def numpy_to_pathpatch(arr):
 
     Parameters
     ----------
-    arr : ndarray
+    arr : :class:`numpy:numpy.ndarray`
         numpy array of Polygon/Multipolygon vertices
 
     Returns
     -------
-    array : ndarray
+    array : :class:`numpy:numpy.ndarray`
         of matplotlib.patches.PathPatch objects
     """
     paths = []
@@ -1304,7 +1356,7 @@ def numpy_to_pathpatch(arr):
             path = Path(vert, code)
             paths.append(patches.PathPatch(path))
         else:
-            path = Path(item, [1] + (len(item)-1) * [2])
+            path = Path(item, [1] + (len(item) - 1) * [2])
             paths.append(patches.PathPatch(path))
 
     return np.array(paths)
@@ -1313,22 +1365,23 @@ def numpy_to_pathpatch(arr):
 def mask_from_bbox(x, y, bbox, polar=False):
     """Return 2-d index array based on spatial selection from a bounding box.
 
-    Use this function to create a 2-d boolean mask from 2-d arrays of grids points.
+    Use this function to create a 2-d boolean mask from 2-d arrays of grids
+    points.
 
     .. versionadded:: 0.7.0
 
     Parameters
     ----------
-    x : ndarray
+    x : :class:`numpy:numpy.ndarray`
         of shape (num rows, num columns)
         x (Cartesian) coordinates
-    y : ndarray
+    y : :class:`numpy:numpy.ndarray`
         of shape (num rows, num columns)
         y (Cartesian) coordinates
     bbox : dict
         dictionary with keys "left", "right", "bottom", "top"
         These must refer to the same Cartesian reference system as x and y
-    polar : bool,
+    polar : bool
         if True, x, y are aligned polar (azimuth x range)
 
     Returns
@@ -1387,19 +1440,19 @@ def mask_from_bbox(x, y, bbox, polar=False):
         if imin > imax:
             mask[:imax, jmin:jmax] = True
             mask[imin:, jmin:jmax] = True
-            shape = (int(ar[maxind]), jmax-jmin)
+            shape = (int(ar[maxind]), jmax - jmin)
         else:
             mask[imin:imax, jmin:jmax] = True
-            shape = (int(ar[maxind]), jmax-jmin)
+            shape = (int(ar[maxind]), jmax - jmin)
 
     else:
 
         if iur > ill:
             mask[ill:iur, jll:jur] = True
-            shape = (iur-ill, jur-jll)
+            shape = (iur - ill, jur - jll)
         else:
             mask[iur:ill, jll:jur] = True
-            shape = (ill-iur, jur-jll)
+            shape = (ill - iur, jur - jll)
 
     return mask, shape
 
@@ -1412,8 +1465,8 @@ def angle_between(source_angle, target_angle):
     source_angle : starting angle
     target_angle : target angle
     """
-    sin1 = np.sin(np.radians(target_angle)-np.radians(source_angle))
-    cos1 = np.cos(np.radians(target_angle)-np.radians(source_angle))
+    sin1 = np.sin(np.radians(target_angle) - np.radians(source_angle))
+    cos1 = np.cos(np.radians(target_angle) - np.radians(source_angle))
     return np.rad2deg(np.arctan2(sin1, cos1))
 
 
@@ -1440,7 +1493,7 @@ def get_centroid(polyg):
 
     Parameters
     ----------
-    polyg : ndarray
+    polyg : :class:`numpy:numpy.ndarray`
         of shape (num vertices, 2) or ogr.Geometry object
 
     Returns
@@ -1459,7 +1512,8 @@ def grid_centers_to_vertices(x, y, dx, dy):
     Warning
     -------
     This has to be done in the "native" grid projection.
-    Once you reprojected the coordinates, this trivial function cannot be used to compute vertices from center points.
+    Once you reprojected the coordinates, this trivial function cannot be used
+    to compute vertices from center points.
 
     Parameters
     ----------
@@ -1475,10 +1529,10 @@ def grid_centers_to_vertices(x, y, dx, dy):
     out : 3-d array
         of vertices for each grid cell of shape (n grid points,5, 2)
     """
-    top = y + dy/2
-    left = x - dx/2
-    right = x + dy/2
-    bottom = y - dy/2
+    top = y + dy / 2
+    left = x - dx / 2
+    right = x + dy / 2
+    bottom = y - dy / 2
 
     verts = np.vstack(([left.ravel(), bottom.ravel()],
                        [right.ravel(), bottom.ravel()],
